"""Українськiй мовний пакет."""

LANG_UK = {
    "code": "uk",
    "name": "Українська",

    # Часті тріграми для визначення мови
    "trigrams": [
        " на", "на ", " не", "не ", " пр", " за", "що ", "ого", "ння",
        "ани", "ати", "ств", " ко", "про", " ви", "ій ", "нн ", "від",
        " ро", "ськ", " по", " до", " як", "ть ", "ів ", "ний", " бу",
        "ні ", "ого", " ма", "ові", "ії ", "ком", "ста", "пер", "ере",
        "при", " мо", "ами", "ень", " де", "тор", "ик ", "ист", "ван",
    ],

    # Стоп-слова
    "stop_words": {
        "і", "в", "на", "з", "по", "для", "не", "від", "за", "до",
        "що", "це", "як", "але", "а", "то", "все", "так", "його",
        "вона", "він", "ми", "ви", "вони", "її", "їх", "був", "бути",
        "б", "же", "чи", "або", "ні", "о", "об", "при", "через",
        "після", "перед", "між", "без", "під", "над", "у", "во",
        "вже", "ще", "також", "тільки", "якщо", "коли", "де", "хто",
        "цей", "ця", "ці", "той", "та", "ті", "свій", "свої",
        "мій", "моя", "мої", "ваш", "ваша", "ваші", "наш",
        "який", "яка", "яке", "які", "котрий", "котра",
    },

    # Канцеляризми → прості заміни
    "bureaucratic": {
        "даний": ["цей", "цей"],
        "дана": ["ця", "ця"],
        "дане": ["це", "це"],
        "здійснювати": ["робити", "проводити"],
        "здійснити": ["зробити", "провести"],
        "здійснює": ["робить", "проводить"],
        "здійснюється": ["робиться", "відбувається"],
        "здійснення": ["проведення", "виконання"],
        "функціонувати": ["працювати", "діяти"],
        "функціонує": ["працює", "діє"],
        "функціонування": ["робота", "дія"],
        "реалізовувати": ["робити", "виконувати"],
        "реалізувати": ["зробити", "виконати"],
        "реалізація": ["виконання", "створення"],
        "надавати": ["давати", "передавати"],
        "надає": ["дає", "передає"],
        "забезпечувати": ["давати", "створювати"],
        "забезпечує": ["дає", "створює"],
        "забезпечення": ["створення", "підтримка"],
        "характеризуватися": ["вирізнятися", "мати"],
        "характеризується": ["вирізняється", "має"],
        "зумовлювати": ["визначати", "спричиняти"],
        "зумовлює": ["визначає", "спричиняє"],
        "зумовлений": ["спричинений", "пов'язаний з"],
        "засобом": ["за допомогою", "через"],
        "внаслідок": ["через", "тому що"],
        "з метою": ["для", "щоб"],
        "на підставі": ["за", "на основі"],
        "зважаючи": ["через", "тому що"],
        "у процесі": ["при", "під час"],
        "в обов'язковому порядку": ["обов'язково", "неодмінно"],
        "належним чином": ["правильно", "як треба"],
        "відповідний": ["потрібний", "підходящий"],
        "відповідним чином": ["правильно", "підходяще"],
        "будь-яким чином": ["якось", "будь-як"],
        "значною мірою": ["багато в чому", "сильно"],
        "достатньою мірою": ["достатньо", "цілком"],
        "повною мірою": ["повністю", "цілком"],
        "найбільш": ["особливо", "надзвичайно"],
        "найменш": ["найменше", "найслабше"],
        "потенційний": ["можливий", "імовірний"],
        "безпосередньо": ["прямо", "одразу"],
        "надалі": ["потім", "далі"],
        "надзвичайно": ["дуже", "вкрай"],
        "суттєво": ["сильно", "помітно"],
        "розташовувати": ["мати", "володіти"],
        "ускладнено": ["складно", "важко"],
        "негайно": ["одразу", "зараз же"],
        "доцільно": ["розумно", "має сенс"],
        "недоцільно": ["не варто", "немає сенсу"],
        "належить": ["потрібно", "слід"],
        "вищезазначений": ["цей", "зазначений вище"],
        "вищезгаданий": ["цей", "згаданий вище"],
        "нижченаведений": ["наступний", "такий"],
        # === v0.11.0 massive expansion ===
        "акумулювати": ["збирати", "накопичувати"],
        "акумулює": ["збирає", "накопичує"],
        "анулювати": ["скасувати", "відкликати"],
        "анулює": ["скасовує", "відкликає"],
        "апелювати": ["звертатися", "посилатися"],
        "апелює": ["звертається", "посилається"],
        "апробувати": ["перевірити", "випробувати"],
        "апробує": ["перевіряє", "випробовує"],
        "аргументувати": ["обґрунтувати", "пояснити"],
        "аргументує": ["обґрунтовує", "пояснює"],
        "базуватися": ["будуватися", "спиратися"],
        "базується": ["будується", "спирається"],
        "верифікувати": ["перевірити", "підтвердити"],
        "верифікує": ["перевіряє", "підтверджує"],
        "візуалізувати": ["показати", "зобразити"],
        "візуалізує": ["показує", "зображає"],
        "генерувати": ["створювати", "породжувати"],
        "генерує": ["створює", "породжує"],
        "детермінувати": ["визначати", "задавати"],
        "детермінує": ["визначає", "задає"],
        "диференціювати": ["розрізняти", "розділяти"],
        "диференціює": ["розрізняє", "розділяє"],
        "домінувати": ["переважати", "панувати"],
        "домінує": ["переважає", "панує"],
        "дублювати": ["повторювати", "копіювати"],
        "дублює": ["повторює", "копіює"],
        "ідентифікувати": ["визначити", "виявити"],
        "ідентифікує": ["визначає", "виявляє"],
        "ілюструвати": ["показувати", "демонструвати"],
        "ілюструє": ["показує", "підтверджує"],
        "імплементувати": ["впровадити", "застосувати"],
        "імплементує": ["впроваджує", "застосовує"],
        "ініціювати": ["почати", "запустити"],
        "ініціює": ["починає", "запускає"],
        "інспектувати": ["перевіряти", "оглядати"],
        "інспектує": ["перевіряє", "оглядає"],
        "інтегрувати": ["об'єднувати", "включати"],
        "інтегрує": ["об'єднує", "включає"],
        "інтерпретувати": ["тлумачити", "пояснювати"],
        "інтерпретує": ["тлумачить", "пояснює"],
        "інформувати": ["повідомляти", "сповіщати"],
        "інформує": ["повідомляє", "сповіщає"],
        "класифікувати": ["розділяти", "групувати"],
        "класифікує": ["розділяє", "групує"],
        "компенсувати": ["відшкодувати", "заповнити"],
        "компенсує": ["відшкодовує", "заповнює"],
        "конкретизувати": ["уточнити", "пояснити"],
        "конкретизує": ["уточнює", "пояснює"],
        "консолідувати": ["об'єднувати", "зміцнювати"],
        "консолідує": ["об'єднує", "зміцнює"],
        "констатувати": ["зазначати", "фіксувати"],
        "констатує": ["зазначає", "фіксує"],
        "контролювати": ["стежити", "перевіряти"],
        "контролює": ["стежить", "перевіряє"],
        "координувати": ["узгоджувати", "налагоджувати"],
        "координує": ["узгоджує", "налагоджує"],
        "коригувати": ["виправляти", "поправляти"],
        "коригує": ["виправляє", "поправляє"],
        "ліквідувати": ["усунути", "прибрати"],
        "ліквідує": ["усуває", "прибирає"],
        "лімітувати": ["обмежувати", "стримувати"],
        "лімітує": ["обмежує", "стримує"],
        "локалізувати": ["знайти", "визначити місце"],
        "локалізує": ["знаходить", "визначає місце"],
        "максимізувати": ["збільшити", "підсилити"],
        "максимізує": ["збільшує", "підсилює"],
        "мінімізувати": ["зменшити", "знизити"],
        "мінімізує": ["зменшує", "знижує"],
        "модернізувати": ["оновити", "покращити"],
        "модернізує": ["оновлює", "покращує"],
        "модифікувати": ["змінити", "поправити"],
        "модифікує": ["змінює", "поправляє"],
        "мотивувати": ["спонукати", "надихати"],
        "мотивує": ["спонукає", "надихає"],
        "нівелювати": ["згладжувати", "зменшувати"],
        "нівелює": ["згладжує", "зменшує"],
        "оптимізувати": ["покращити", "налаштувати"],
        "оптимізує": ["покращує", "налаштовує"],
        "позиціонувати": ["розміщувати", "виставляти"],
        "позиціонує": ["розміщує", "виставляє"],
        "пролонгувати": ["продовжити", "подовжити"],
        "пролонгує": ["продовжує", "подовжує"],
        "регламентувати": ["визначати правила", "встановлювати порядок"],
        "регламентує": ["визначає правила", "встановлює порядок"],
        "регулювати": ["налаштовувати", "керувати"],
        "регулює": ["налаштовує", "керує"],
        "резюмувати": ["підсумувати", "узагальнити"],
        "резюмує": ["підсумовує", "узагальнює"],
        "санкціонувати": ["дозволити", "схвалити"],
        "санкціонує": ["дозволяє", "схвалює"],
        "систематизувати": ["упорядкувати", "привести до ладу"],
        "систематизує": ["упорядковує", "приводить до ладу"],
        "стабілізувати": ["зміцнити", "вирівняти"],
        "стабілізує": ["зміцнює", "вирівнює"],
        "стимулювати": ["спонукати", "підштовхувати"],
        "стимулює": ["спонукає", "підштовхує"],
        "структурувати": ["упорядкувати", "організувати"],
        "структурує": ["упорядковує", "організовує"],
        "трансформувати": ["змінити", "переробити"],
        "трансформує": ["змінює", "переробляє"],
        "фіксувати": ["зазначати", "записувати"],
        "фіксує": ["зазначає", "записує"],
        "формулювати": ["висловлювати", "викладати"],
        "формулює": ["висловлює", "викладає"],
        # --- Прикметники / прислівники ---
        "актуальний": ["важливий", "нагальний"],
        "актуальна": ["важлива", "нагальна"],
        "аналогічний": ["схожий", "такий самий"],
        "аналогічна": ["схожа", "така сама"],
        "безальтернативний": ["єдиний", "неминучий"],
        "деструктивний": ["руйнівний", "шкідливий"],
        "додатковий": ["ще один", "добавочний"],
        "додаткова": ["ще одна", "добавочна"],
        "ідентичний": ["однаковий", "точно такий самий"],
        "ідентична": ["однакова", "точно така сама"],
        "індивідуальний": ["особистий", "власний"],
        "індивідуальна": ["особиста", "власна"],
        "колосальний": ["величезний", "грандіозний"],
        "колосальна": ["величезна", "грандіозна"],
        "комплексний": ["складний", "багатосторонній"],
        "комплексна": ["складна", "багатостороння"],
        "конструктивний": ["корисний", "діловий"],
        "конструктивна": ["корисна", "ділова"],
        "масштабний": ["великий", "обширний"],
        "масштабна": ["велика", "обширна"],
        "негативний": ["поганий", "від'ємний"],
        "негативна": ["погана", "від'ємна"],
        "оперативно": ["швидко", "без зволікань"],
        "перспективний": ["обіцяючий", "майбутній"],
        "перспективна": ["обіцяюча", "майбутня"],
        "позитивний": ["хороший", "додатний"],
        "позитивна": ["хороша", "додатна"],
        "пріоритетний": ["головний", "першочерговий"],
        "пріоритетна": ["головна", "першочергова"],
        "специфічний": ["особливий", "характерний"],
        "специфічна": ["особлива", "характерна"],
        "стратегічний": ["важливий", "ключовий"],
        "стратегічна": ["важлива", "ключова"],
        "суттєвий": ["помітний", "серйозний"],
        "суттєва": ["помітна", "серйозна"],
        "унікальний": ["єдиний у своєму роді", "неповторний"],
        "унікальна": ["єдина у своєму роді", "неповторна"],
        "фундаментальний": ["основний", "базовий"],
        "фундаментальна": ["основна", "базова"],
        # --- Іменники ---
        "аспект": ["бік", "грань"],
        "аспекти": ["боки", "грані"],
        "дефіцит": ["нестача", "брак"],
        "імплементація": ["впровадження", "застосування"],
        "компетенція": ["вміння", "навичка"],
        "компетенції": ["вміння", "навички"],
        "моніторинг": ["спостереження", "відстеження"],
        "парадигма": ["модель", "підхід"],
        "потенціал": ["можливості", "сила"],
        "пріоритет": ["головне", "першочергове"],
        "тенденція": ["тренд", "напрямок"],
        "тенденції": ["тренди", "напрямки"],
        "трансформація": ["зміна", "перебудова"],
        "фактор": ["причина", "обставина"],
        "фактори": ["причини", "обставини"],
        "ефективність": ["результативність", "віддача"],
        # === v0.12.0 expansion ===
        "адаптувати": ["пристосувати", "підлаштувати"],
        "адаптує": ["пристосовує", "підлаштовує"],
        "активізувати": ["посилити", "пожвавити"],
        "активізує": ["посилює", "пожвавлює"],
        "делегувати": ["доручити", "передати"],
        "делегує": ["доручає", "передає"],
        "демонструвати": ["показувати", "являти"],
        "демонструє": ["показує", "являє"],
        "деталізувати": ["уточнити", "розписати"],
        "деталізує": ["уточнює", "розписує"],
        "діагностувати": ["визначити", "виявити хворобу"],
        "діагностує": ["визначає", "виявляє"],
        "дискутувати": ["обговорювати", "сперечатися"],
        "дискутує": ["обговорює", "сперечається"],
        "документувати": ["записувати", "занотовувати"],
        "документує": ["записує", "занотовує"],
        "експлуатувати": ["використовувати", "вживати"],
        "експлуатує": ["використовує", "вживає"],
        "елімінувати": ["усунути", "видалити"],
        "елімінує": ["усуває", "видаляє"],
        "ескалувати": ["загострити", "посилити"],
        "ескалує": ["загострює", "посилює"],
        "фасилітувати": ["полегшити", "сприяти"],
        "фасилітує": ["полегшує", "сприяє"],
        "фінансувати": ["оплачувати", "спонсорувати"],
        "фінансує": ["оплачує", "спонсорує"],
        "фокусувати": ["зосереджувати", "спрямовувати"],
        "фокусує": ["зосереджує", "спрямовує"],
        "формалізувати": ["оформити", "узаконити"],
        "формалізує": ["оформлює", "узаконює"],
        "гарантувати": ["забезпечити", "запевнити"],
        "гарантує": ["забезпечує", "запевняє"],
        "гармонізувати": ["узгодити", "привести у відповідність"],
        "гармонізує": ["узгоджує", "приводить у відповідність"],
        "ігнорувати": ["не зважати", "пропускати"],
        "ігнорує": ["не зважає", "пропускає"],
        "каталогізувати": ["описати", "переписати"],
        "каталогізує": ["описує", "переписує"],
        "кваліфікувати": ["визначити як", "оцінити"],
        "кваліфікує": ["визначає як", "оцінює"],
        "конвертувати": ["перетворити", "обміняти"],
        "конвертує": ["перетворює", "обмінює"],
        "культивувати": ["плекати", "виховувати"],
        "культивує": ["плекає", "виховує"],
        "легітимізувати": ["узаконити", "визнати законним"],
        "легітимізує": ["узаконює", "визнає законним"],
        "маніпулювати": ["підлаштовувати", "керувати приховано"],
        "маніпулює": ["підлаштовує", "керує приховано"],
        "маркувати": ["позначати", "ставити мітку"],
        "маркує": ["позначає", "мітить"],
        "нейтралізувати": ["знешкодити", "усунути вплив"],
        "нейтралізує": ["знешкоджує", "усуває вплив"],
        "нормалізувати": ["привести до ладу", "впорядкувати"],
        "нормалізує": ["приводить до ладу", "впорядковує"],
        "орієнтувати": ["спрямовувати", "направляти"],
        "орієнтує": ["спрямовує", "направляє"],
        "пріоритезувати": ["визначити головне", "розставити пріоритети"],
        "пріоритезує": ["визначає головне", "розставляє пріоритети"],
        "прогнозувати": ["передбачати", "очікувати"],
        "прогнозує": ["передбачає", "очікує"],
        "пропагувати": ["поширювати", "просувати"],
        "пропагує": ["поширює", "просуває"],
        "проєктувати": ["створювати план", "планувати"],
        "проєктує": ["створює план", "планує"],
        "рекомендувати": ["порадити", "запропонувати"],
        "рекомендує": ["радить", "пропонує"],
        "репрезентувати": ["представляти", "втілювати"],
        "репрезентує": ["представляє", "втілює"],
        "ротувати": ["змінювати по черзі", "чергувати"],
        "ротує": ["змінює по черзі", "чергує"],
        "сертифікувати": ["підтвердити якість", "засвідчити"],
        "сертифікує": ["підтверджує якість", "засвідчує"],
        "сигналізувати": ["повідомляти", "вказувати"],
        "сигналізує": ["повідомляє", "вказує"],
        "символізувати": ["означати", "уособлювати"],
        "символізує": ["означає", "уособлює"],
        "синхронізувати": ["узгодити в часі", "звести докупи"],
        "синхронізує": ["узгоджує в часі", "зводить докупи"],
        "специфікувати": ["уточнити", "визначити детально"],
        "специфікує": ["уточнює", "визначає детально"],
        "тестувати": ["перевіряти", "випробовувати"],
        "тестує": ["перевіряє", "випробовує"],
        "транслювати": ["передавати", "поширювати"],
        "транслює": ["передає", "поширює"],
        "утилізувати": ["переробити", "позбутися"],
        "утилізує": ["переробляє", "позбувається"],
        # --- Прикметники / прислівники (v0.12.0) ---
        "автономний": ["самостійний", "незалежний"],
        "автономна": ["самостійна", "незалежна"],
        "альтернативний": ["інший", "запасний"],
        "альтернативна": ["інша", "запасна"],
        "домінантний": ["панівний", "провідний"],
        "домінантна": ["панівна", "провідна"],
        "екстраординарний": ["надзвичайний", "винятковий"],
        "ексклюзивний": ["виключний", "єдиний"],
        "ексклюзивна": ["виключна", "єдина"],
        "категоричний": ["рішучий", "безапеляційний"],
        "категорична": ["рішуча", "безапеляційна"],
        "радикальний": ["докорінний", "рішучий"],
        "радикальна": ["докорінна", "рішуча"],
        "систематичний": ["послідовний", "планомірний"],
        "систематична": ["послідовна", "планомірна"],
        "превентивний": ["попереджувальний", "запобіжний"],
        "превентивна": ["попереджувальна", "запобіжна"],
        "прецедентний": ["показовий", "типовий"],
        "прецедентна": ["показова", "типова"],
        "тактичний": ["практичний", "прикладний"],
        "тактична": ["практична", "прикладна"],
        "пропорційний": ["відповідний", "співмірний"],
        "пропорційна": ["відповідна", "співмірна"],
        "раціональний": ["розумний", "розсудливий"],
        "раціональна": ["розумна", "розсудлива"],
        "релевантний": ["доречний", "стосовний"],
        "релевантна": ["доречна", "стосовна"],
        # --- Іменники (v0.12.0) ---
        "альтернатива": ["заміна", "інший варіант"],
        "контекст": ["обставини", "умови"],
        "концепція": ["ідея", "задум"],
        "критерій": ["мірило", "ознака"],
        "критерії": ["мірила", "ознаки"],
        "резонанс": ["відгук", "відлуння"],
        "конфігурація": ["налаштування", "будова"],
        "кореляція": ["зв'язок", "залежність"],
        "номенклатура": ["перелік", "список"],
        "специфіка": ["особливість", "своєрідність"],
        "інфраструктура": ["основа", "база"],
        "методологія": ["підхід", "метод"],
        # --- v0.27.0 expansion: дієслова ---
        "забезпечувати": ["давати", "гарантувати"],
        "забезпечує": ["дає", "гарантує"],
        "здійснювати вплив": ["впливати", "діяти"],
        "зумовлювати": ["спричиняти", "викликати"],
        "зумовлює": ["спричиняє", "викликає"],
        "обумовлювати": ["пояснювати", "визначати"],
        "обумовлює": ["пояснює", "визначає"],
        "уможливлювати": ["дозволяти", "давати можливість"],
        "уможливлює": ["дозволяє", "дає можливість"],
        "передбачати": ["очікувати", "планувати"],
        "передбачає": ["очікує", "планує"],
        "характеризувати": ["описувати", "окреслювати"],
        "характеризує": ["описує", "окреслює"],
        "ідентифікувати": ["розпізнати", "визначити"],
        "ідентифікує": ["розпізнає", "визначає"],
        "акумулювати": ["накопичувати", "збирати"],
        "акумулює": ["накопичує", "збирає"],
        "верифікувати": ["перевірити", "підтвердити"],
        "верифікує": ["перевіряє", "підтверджує"],
        "імплементувати": ["впровадити", "запустити"],
        "імплементує": ["впроваджує", "запускає"],
        "оптимізувати": ["покращити", "вдосконалити"],
        "оптимізує": ["покращує", "вдосконалює"],
        "трансформувати": ["перетворити", "змінити"],
        "трансформує": ["перетворює", "змінює"],
        "генерувати": ["створювати", "породжувати"],
        "генерує": ["створює", "породжує"],
        "демонструвати": ["показувати", "являти"],
        "демонструє": ["показує", "являє"],
        "ініціювати": ["розпочати", "запустити"],
        "ініціює": ["розпочинає", "запускає"],
        "модифікувати": ["змінити", "переробити"],
        "модифікує": ["змінює", "переробляє"],
        "стимулювати": ["підштовхувати", "заохочувати"],
        "стимулює": ["підштовхує", "заохочує"],
        "інтегрувати": ["поєднати", "об'єднати"],
        "інтегрує": ["поєднує", "об'єднує"],
        "координувати": ["узгоджувати", "керувати"],
        "координує": ["узгоджує", "керує"],
        "формулювати": ["виражати", "описувати"],
        "формулює": ["виражає", "описує"],
        # --- v0.27.0 expansion: прикметники ---
        "оптимальний": ["найкращий", "найвдаліший"],
        "оптимальна": ["найкраща", "найвдаліша"],
        "системний": ["цілісний", "упорядкований"],
        "системна": ["цілісна", "упорядкована"],
        "стратегічний": ["довгостроковий", "ключовий"],
        "стратегічна": ["довгострокова", "ключова"],
        "пріоритетний": ["першочерговий", "головний"],
        "пріоритетна": ["першочергова", "головна"],
        "превентивний": ["запобіжний", "попереджувальний"],
        "превентивна": ["запобіжна", "попереджувальна"],
        "інтенсивний": ["активний", "потужний"],
        "інтенсивна": ["активна", "потужна"],
        "консолідований": ["об'єднаний", "зведений"],
        "консолідована": ["об'єднана", "зведена"],
        "репрезентативний": ["представницький", "показовий"],
        "репрезентативна": ["представницька", "показова"],
        "ексклюзивний": ["виключний", "особливий"],
        "ексклюзивна": ["виключна", "особлива"],
        "перманентний": ["постійний", "тривалий"],
        "перманентна": ["постійна", "тривала"],
        "домінуючий": ["переважний", "панівний"],
        "домінуюча": ["переважна", "панівна"],
        "маргінальний": ["другорядний", "периферійний"],
        "маргінальна": ["другорядна", "периферійна"],
        "деструктивний": ["руйнівний", "шкідливий"],
        "деструктивна": ["руйнівна", "шкідлива"],
        "конструктивний": ["корисний", "плідний"],
        "конструктивна": ["корисна", "плідна"],
        "латентний": ["прихований", "непомітний"],
        "латентна": ["прихована", "непомітна"],
        # --- v0.27.0 expansion: іменники ---
        "парадигма": ["модель", "зразок"],
        "тенденція": ["тренд", "напрямок"],
        "перспектива": ["можливість", "майбутнє"],
        "прерогатива": ["право", "привілей"],
        "компетенція": ["обізнаність", "вміння"],
        "компетенції": ["знання", "вміння"],
        "детермінанта": ["чинник", "визначальний фактор"],
        "симптоматика": ["ознаки", "прояви"],
        "пролонгація": ["продовження", "подовження"],
        "сегментація": ["поділ", "розподіл"],
        "диверсифікація": ["урізноманітнення", "розширення"],
        "валідація": ["перевірка", "підтвердження"],
        "кон'юнктура": ["обстановка", "ситуація"],
        "номінація": ["назва", "найменування"],
        "генерація": ["створення", "продукування"],
        "інтерпретація": ["тлумачення", "пояснення"],
        "модернізація": ["оновлення", "осучаснення"],
        "локалізація": ["розміщення", "місцезнаходження"],
        "дислокація": ["розташування", "місцезнаходження"],
        "індикатор": ["показник", "мірило"],
        "ресурсозабезпечення": ["постачання ресурсів", "наповнення ресурсами"],
        "функціонал": ["можливості", "набір функцій"],
        "дефініція": ["визначення", "означення"],
        "пріоритет": ["першочерговість", "головне"],
        "пріоритети": ["першочергові завдання", "головне"],
        "менеджмент": ["управління", "керівництво"],
        "маркетинг": ["просування", "збут"],
        "моніторинг": ["стеження", "нагляд"],
    },

    # Фразові канцеляризми
    "bureaucratic_phrases": {
        "є одним із": ["— один із", "один із"],
        "є одним з": ["— один з", "один з"],
        "являє собою": ["— це", "це"],
        "являють собою": ["— це", "це"],
        "надавати сприяння": ["допомагати", "сприяти"],
        "надає сприяння": ["допомагає", "сприяє"],
        "приймати рішення": ["вирішувати", "обирати"],
        "прийняти рішення": ["вирішити", "обрати"],
        "здійснювати оплату": ["платити", "оплачувати"],
        "справляти вплив": ["впливати", "діяти"],
        "справляє вплив": ["впливає", "діє"],
        "у тому випадку, якщо": ["якщо", "коли"],
        "у тому випадку якщо": ["якщо", "коли"],
        "у зв'язку з тим, що": ["тому що", "оскільки"],
        "у зв'язку з тим що": ["тому що", "оскільки"],
        "з причини того, що": ["тому що", "оскільки"],
        "зважаючи на те, що": ["тому що", "оскільки"],
        "володіти здатністю": ["могти", "вміти"],
        "володіє здатністю": ["може", "вміє"],
        "на даний час": ["зараз", "тепер"],
        "на теперішній час": ["зараз", "тепер"],
        "на сьогоднішній день": ["сьогодні", "зараз"],
        "на поточний момент": ["зараз", "поки"],
        "у кінцевому рахунку": ["у підсумку", "зрештою"],
        "у кінцевому підсумку": ["у підсумку", "зрештою"],
        "протягом тривалого часу": ["давно", "довго"],
        "у рамках": ["у", "в"],
        "відповідно до": ["за", "згідно з"],
        "з точки зору": ["для", "з погляду"],
        "необхідно зазначити": ["важливо", "варто сказати"],
        "необхідно підкреслити": ["важливо", "варто зазначити"],
        "слід зазначити": ["важливо", "варто сказати"],
        "варто зазначити, що": ["важливо, що", "зауважимо, що"],
        "не можна не зазначити": ["варто сказати", "важливо"],
        "важливо підкреслити, що": ["важливо, що", "варто сказати, що"],
        # === v0.11.0 massive expansion ===
        "для того, щоб": ["щоб", "для"],
        "для того щоб": ["щоб", "для"],
        "мати місце": ["відбуватися", "бути"],
        "має місце": ["відбувається", "є"],
        "відіграє ключову роль": ["важливий", "сильно впливає"],
        "несе відповідальність": ["відповідає", "відповідальний"],
        "проводити аналіз": ["аналізувати", "розбирати"],
        "проводить аналіз": ["аналізує", "розбирає"],
        "проводити моніторинг": ["стежити", "відстежувати"],
        "проводить моніторинг": ["стежить", "відстежує"],
        "з урахуванням того, що": ["враховуючи, що", "раз"],
        "на підставі вищесказаного": ["тому", "отже"],
        "приділяти увагу": ["звертати увагу", "займатися"],
        "приділяє увагу": ["звертає увагу", "займається"],
        "слід мати на увазі": ["врахуйте", "пам'ятайте"],
        "в якості прикладу": ["наприклад", "скажімо"],
        # === v0.12.0 expansion ===
        "брати участь у": ["долучатися до", "бути в"],
        "бере участь у": ["долучається до", "є частиною"],
        "вести діяльність": ["працювати", "займатися"],
        "веде діяльність": ["працює", "займається"],
        "виступати у ролі": ["бути", "діяти як"],
        "виступає у ролі": ["є", "діє як"],
        "дотримуватися думки": ["вважати", "думати"],
        "дотримується думки": ["вважає", "думає"],
        "здійснювати контроль": ["контролювати", "стежити"],
        "здійснює контроль": ["контролює", "стежить"],
        "здійснювати вплив на": ["впливати на", "діяти на"],
        "здійснює вплив на": ["впливає на", "діє на"],
        "нести відповідальність за": ["відповідати за", "бути відповідальним за"],
        "виявляти бажання": ["хотіти", "бажати"],
        "виявляє бажання": ["хоче", "бажає"],
        "у відповідності до": ["відповідно до", "згідно з"],
        "у відповідності з": ["відповідно до", "згідно з"],
        "за відсутності": ["без", "коли немає"],
        "за наявності": ["якщо є", "коли є"],
        "в частині": ["щодо", "стосовно"],
        "на предмет": ["щодо", "про"],
        "за рахунок": ["завдяки", "через"],
        "у свою чергу": ["зі свого боку", "натомість"],
        "в обсязі": ["на суму", "у розмірі"],
        "мати можливість": ["могти", "бути в змозі"],
        "має можливість": ["може", "здатний"],
        "в силу того, що": ["тому що", "оскільки"],
        "з огляду на те, що": ["оскільки", "враховуючи що"],
        "з огляду на": ["враховуючи", "через"],
        "на користь": ["для", "задля"],
        "в цілях": ["для", "заради"],
        # --- v0.27.0 expansion ---
        "здійснювати планування": ["планувати", "продумувати"],
        "здійснює планування": ["планує", "продумує"],
        "здійснювати перевірку": ["перевіряти", "звіряти"],
        "здійснює перевірку": ["перевіряє", "звіряє"],
        "здійснювати підготовку": ["готувати", "готуватися"],
        "здійснює підготовку": ["готує", "готується"],
        "здійснювати відбір": ["обирати", "відбирати"],
        "здійснює відбір": ["обирає", "відбирає"],
        "здійснювати доставку": ["доставляти", "привозити"],
        "здійснює доставку": ["доставляє", "привозить"],
        "здійснювати оцінку": ["оцінювати", "визначати"],
        "здійснює оцінку": ["оцінює", "визначає"],
        "здійснювати пошук": ["шукати", "розшукувати"],
        "здійснює пошук": ["шукає", "розшукує"],
        "вносити корективи": ["правити", "змінювати"],
        "вносить корективи": ["править", "змінює"],
        "надавати допомогу": ["допомагати", "підтримувати"],
        "надає допомогу": ["допомагає", "підтримує"],
        "прийти до висновку": ["зрозуміти", "усвідомити"],
        "приходить до висновку": ["розуміє", "усвідомлює"],
        "підлягає розгляду": ["розглядається", "буде розглянуто"],
        "з метою забезпечення": ["щоб забезпечити", "для"],
        "з метою реалізації": ["щоб реалізувати", "для"],
        "з метою покращення": ["щоб покращити", "для"],
        "з метою підвищення": ["щоб підвищити", "для"],
        "з метою оптимізації": ["щоб оптимізувати", "для"],
        "є результатом": ["виникає через", "пояснюється"],
        "є наслідком": ["виникає через", "пов'язано з"],
        "є свідченням": ["показує", "доводить"],
        "є підтвердженням": ["підтверджує", "доводить"],
        "є запорукою": ["забезпечує", "гарантує"],
        "ставити за мету": ["прагнути", "мати на меті"],
        "ставить за мету": ["прагне", "хоче"],
        "мати місце бути": ["відбуватися", "траплятися"],
        "вживати заходів": ["діяти", "робити"],
        "вживає заходів": ["діє", "робить"],
        "здійснювати діяльність": ["працювати", "діяти"],
        "здійснює діяльність": ["працює", "діє"],
        "має на меті": ["прагне", "хоче"],
        "полягає в тому, що": ["означає, що", "тобто"],
        "полягає в тому що": ["означає, що", "тобто"],
        "зводиться до того, що": ["означає, що", "тобто"],
        "виходячи з вищевикладеного": ["тому", "отже"],
        "беручи до уваги": ["враховуючи", "зважаючи на"],
    },

    # Слова-зв'язки, типові для ШІ → заміни
    "ai_connectors": {
        "Однак": ["Але", "Втім", "Проте", "Щоправда"],
        "Проте": ["Але", "Втім", "Однак", "Щоправда"],
        "Тим не менш": ["Але", "Все ж", "І все-таки", "Щоправда"],
        "Разом з тим": ["Але", "При цьому", "Хоча"],
        "Крім того": ["Ще", "Також", "І ще", "Плюс"],
        "Більш того": ["І ще", "До того ж", "Плюс"],
        "Окрім цього": ["Ще", "Також", "І"],
        "Таким чином": ["У підсумку", "Тому", "Отже", "Тож"],
        "Отже": ["Значить", "Тому", "Тож"],
        "Безумовно": ["Звісно", "Так", "Точно"],
        "Безсумнівно": ["Звісно", "Точно", "Так"],
        "На завершення": ["Підсумовуючи", "Наостанок", "Наприкінці"],
        "Передусім": ["Спочатку", "По-перше", "Для початку"],
        "В першу чергу": ["Спочатку", "Передусім", "Для початку"],
        "Не менш важливо": ["Важливо й те", "Також важливо", "І ще"],
        "З іншого боку": ["А ось", "Натомість", "Зате"],
        "Загалом": ["У цілому", "Якщо коротко", "Взагалі"],
        "Зокрема": ["Наприклад", "Скажімо", "Приміром"],
        "Варто підкреслити": ["Важливо", "Зауважимо", "Відзначимо"],
        "Необхідно розуміти": ["Важливо розуміти", "Врахуйте", "Майте на увазі"],
        "Важливо враховувати": ["Врахуйте", "Майте на увазі", "Не забувайте"],
        "Підсумовуючи": ["У підсумку", "Якщо коротко", "Загалом"],
        "Виходячи з цього": ["Тому", "Тож", "Значить"],
        "Як наслідок": ["Тому", "Через це", "У підсумку"],
        # === v0.11.0 massive expansion ===
        "Слід зауважити": ["Варто сказати", "Помітно", "І ось що"],
        "Варто зазначити": ["Важливо", "Майте на увазі", "Зауважимо"],
        "Слід зазначити, що": ["Варто сказати, що", "Цікаво, що", "Важливо, що"],
        "Необхідно відзначити": ["Варто сказати", "Зауважимо", "Важливо"],
        "Необхідно підкреслити": ["Варто підкреслити", "Важливо", "Примітно"],
        "По-перше": ["Спочатку", "Для початку", "Передусім"],
        "По-друге": ["Далі", "Також", "На додаток"],
        "По-третє": ["І ще", "Нарешті", "Наостанок"],
        "В цілому": ["Загалом", "У цілому", "Якщо загально"],
        "Слід підкреслити": ["Важливо", "Зауважимо", "Відзначимо"],
        "Також варто": ["Ще корисно", "Не завадить", "Плюс до цього"],
        "Важливо розуміти, що": ["Майте на увазі, що", "Врахуйте, що", "Пам'ятайте, що"],
        "Варто врахувати": ["Врахуйте", "Не забувайте", "Майте на увазі"],
        "Наступним кроком": ["Далі", "Після цього", "Потім"],
        "В кінцевому підсумку": ["Наприкінці", "Наостанок", "Зрештою"],
        "В кінцевому рахунку": ["Зрештою", "Наостанок", "У підсумку"],
        "В результаті": ["Як наслідок", "Через це", "Відтак"],
        "Зверніть увагу": ["Подивіться", "Зауважте", "Примітно"],
        "Не менш важливим": ["Важливим є також", "Також суттєвим", "І ще важливо"],
        "Як бачимо": ["Як видно", "Ясно", "Очевидно"],
        "Як доводить практика": ["На практиці", "Як показує досвід", "У реальності"],
        # === v0.12.0 expansion ===
        "У даному контексті": ["Тут", "У цьому разі", "Якщо говорити про це"],
        "Водночас": ["Разом із тим", "Паралельно", "Одночасно"],
        "Відповідно": ["Тому", "Отже", "Значить"],
        "Зрештою": ["У підсумку", "Наприкінці", "Врешті-решт"],
        "Щоправда": ["Але", "Втім", "Хоча"],
        "Натомість": ["Замість цього", "А от", "Зате"],
        "Наразі": ["Зараз", "Тепер", "На цей момент"],
        "Попри це": ["Хоча", "Незважаючи на це", "Але"],
        "Тож": ["Тому", "Відтак", "Отже"],
        "Відтак": ["Тому", "Тож", "Через це"],
        "Утім": ["Але", "Однак", "Та все ж"],
        "Згідно з цим": ["Тому", "Відповідно", "Через це"],
        "У такий спосіб": ["Так", "Цим шляхом", "Таким чином"],
        "З огляду на це": ["Тому", "Через це", "Враховуючи це"],
        "Поза тим": ["Крім того", "Ще", "До того ж"],
        "Понад те": ["Більше того", "До того ж", "Крім того"],
        "Принагідно": ["До речі", "Між іншим", "До слова"],
        "Вочевидь": ["Мабуть", "Схоже", "Напевно"],
        "Вірогідно": ["Мабуть", "Здається", "Схоже на те"],
        "Імовірно": ["Мабуть", "Можливо", "Здається"],
        "Нарешті": ["Зрештою", "Наостанок", "У кінці кінців"],
        "Практично": ["Фактично", "По суті", "Майже"],
        "Головним чином": ["Переважно", "В основному", "Передусім"],
        "У першу чергу": ["Спочатку", "Передусім", "Перш за все"],
        "Цілком очевидно": ["Зрозуміло", "Ясно", "Без сумніву"],
        "Невипадково": ["Не дарма", "Закономірно", "Цілком зрозуміло"],
        "Характерно, що": ["Помітно, що", "Варто сказати, що", "Цікаво, що"],
        "Примітно, що": ["Цікаво, що", "Варто зазначити, що", "Помітно, що"],
        "Саме тому": ["Ось чому", "Через це", "Тому"],
        "Не дивно, що": ["Зрозуміло, що", "Цілком логічно, що", "Очевидно, що"],
        # --- v0.27.0 expansion ---
        "У контексті цього": ["Щодо цього", "Стосовно цього", "У зв'язку з цим"],
        "Необхідно наголосити": ["Варто наголосити", "Підкреслимо", "Зауважимо"],
        "З іншого боку": ["Натомість", "А от", "Водночас"],
        "Саме тому що": ["Тому що", "Адже", "Бо"],
        "Особливо варто": ["Окремо слід", "Найбільше варто", "Зокрема"],
        "Не менш важливо": ["Також важливо", "Ще одне", "Крім того"],
        "Таким чином можна": ["Тож можна", "Значить можна", "Отже можна"],
        "Очевидно, що": ["Зрозуміло, що", "Ясно, що", "Помітно, що"],
        "Безсумнівно": ["Безперечно", "Звісно", "Ясна річ"],
        "Беззаперечно": ["Безумовно", "Без сумніву", "Це точно"],
        "Що стосується": ["Щодо", "Якщо говорити про", "Стосовно"],
        "В свою чергу": ["Натомість", "Зі свого боку", "А от"],
        "Разом із тим": ["Але", "Водночас", "Попри це"],
        "Тим часом": ["А поки", "А тим часом", "Паралельно"],
        "Передусім": ["Насамперед", "Спочатку", "Перш за все"],
        "За умови": ["Якщо", "Коли", "При"],
        "В умовах": ["За", "Коли є", "При"],
        "Як зазначалося": ["Як уже казали", "Як бачимо", "Як відомо"],
        "Як зазначалося раніше": ["Як ми казали", "Як вже було", "Раніше ми писали"],
        "Безумовно важливо": ["Безперечно важливо", "Вкрай важливо", "Точно варто"],
        "Слід акцентувати": ["Наголосимо", "Підкреслимо", "Варто виділити"],
        "Характерною рисою є": ["Відмінна риса —", "Особливість —", "Вирізняється тим, що"],
    },

    # Синоніми для усунення повторів
    "synonyms": {
        "важливий": ["значущий", "суттєвий", "ключовий", "вагомий"],
        "важлива": ["значуща", "суттєва", "ключова", "вагома"],
        "важливе": ["значуще", "суттєве", "ключове", "вагоме"],
        "важливо": ["суттєво", "значуще", "принципово"],
        "великий": ["чималий", "значний", "солідний"],
        "велика": ["чимала", "значна", "солідна"],
        "маленький": ["невеликий", "компактний", "малий", "скромний"],
        "гарний": ["чудовий", "гідний", "якісний", "непоганий"],
        "гарно": ["чудово", "непогано", "гідно", "на рівні"],
        "поганий": ["слабкий", "невдалий", "кепський"],
        "погано": ["слабко", "невдало", "кепсько"],
        "допомагати": ["сприяти", "підтримувати", "допомогти"],
        "допомагає": ["сприяє", "підтримує", "дає можливість"],
        "дозволяє": ["дає можливість", "допомагає", "забезпечує"],
        "використовувати": ["застосовувати", "задіяти", "брати"],
        "використовує": ["застосовує", "задіює", "бере"],
        "отримувати": ["здобувати", "набувати", "діставати"],
        "отримує": ["здобуває", "набуває", "дістає"],
        "створювати": ["формувати", "розробляти", "будувати"],
        "створює": ["формує", "розробляє", "будує"],
        "змінювати": ["перетворювати", "модифікувати", "правити"],
        "змінює": ["перетворює", "модифікує", "править"],
        "показувати": ["демонструвати", "відображати", "розкривати"],
        "показує": ["демонструє", "відображає", "розкриває"],
        "працювати": ["діяти", "трудитися", "функціонувати"],
        "працює": ["діє", "трудиться", "функціонує"],
        "швидко": ["стрімко", "оперативно", "скоро"],
        "повільно": ["поступово", "неквапливо", "плавно"],
        "часто": ["нерідко", "регулярно", "то й діло"],
        "багато": ["чимало", "достатньо", "доволі"],
        "дуже": ["вельми", "вкрай", "доволі"],
        "потрібно": ["варто", "слід", "необхідно"],
        "можна": ["допустимо", "реально", "цілком можливо"],
        "наприклад": ["скажімо", "приміром", "припустимо"],
        "тому": ["через це", "з цієї причини", "відтак"],
        "також": ["теж", "разом з тим", "ще"],
        "зараз": ["тепер", "наразі", "у цей момент"],
        "різний": ["різноманітний", "всілякий", "неоднаковий"],
        "основний": ["головний", "ключовий", "центральний"],
        "значний": ["суттєвий", "помітний", "чималий"],
        "ефективний": ["дієвий", "продуктивний", "результативний"],
        "ефективно": ["дієво", "продуктивно", "результативно"],
        "проблема": ["питання", "труднощі", "завдання"],
        "результат": ["підсумок", "наслідок", "плід"],
        "процес": ["хід", "перебіг", "дія"],
        "спосіб": ["метод", "шлях", "підхід"],
        "мета": ["завдання", "намір", "ціль"],
        "можливість": ["шанс", "варіант", "опція"],
        # === v0.11.0 massive expansion ===
        "новий": ["свіжий", "сучасний", "оновлений"],
        "нова": ["свіжа", "сучасна", "оновлена"],
        "нове": ["свіже", "сучасне", "оновлене"],
        "старий": ["давній", "попередній", "колишній"],
        "стара": ["давня", "попередня", "колишня"],
        "сильний": ["потужний", "міцний", "вагомий"],
        "сильна": ["потужна", "міцна", "вагома"],
        "слабкий": ["незначний", "кволий", "посередній"],
        "слабка": ["незначна", "квола", "посередня"],
        "правильний": ["вірний", "коректний", "точний"],
        "правильна": ["вірна", "коректна", "точна"],
        "правильно": ["вірно", "коректно", "точно"],
        "неправильний": ["хибний", "невірний", "некоректний"],
        "цікавий": ["захопливий", "привабливий", "примітний"],
        "цікава": ["захоплива", "приваблива", "примітна"],
        "цікаво": ["захопливо", "привабливо", "примітно"],
        "простий": ["нескладний", "легкий", "елементарний"],
        "проста": ["нескладна", "легка", "елементарна"],
        "просто": ["нескладно", "легко", "елементарно"],
        "складний": ["непростий", "багатогранний", "важкий"],
        "складна": ["непроста", "багатогранна", "важка"],
        "складно": ["непросто", "важко", "нелегко"],
        "різко": ["раптово", "стрімко", "круто"],
        "добре": ["непогано", "ладно", "гідно"],
        "перший": ["початковий", "стартовий", "вступний"],
        "перша": ["початкова", "стартова", "вступна"],
        "останній": ["кінцевий", "заключний", "фінальний"],
        "остання": ["кінцева", "заключна", "фінальна"],
        "повний": ["цілковитий", "абсолютний", "вичерпний"],
        "повна": ["цілковита", "абсолютна", "вичерпна"],
        "повністю": ["цілковито", "цілком", "абсолютно"],
        "частково": ["почасти", "деякою мірою", "не цілком"],
        "головний": ["основний", "центральний", "провідний"],
        "головна": ["основна", "центральна", "провідна"],
        "один": ["єдиний", "окремий", "поодинокий"],
        "однак": ["але", "втім", "зате"],
        "особливо": ["зокрема", "передусім", "надто"],
        "більше": ["понад", "дедалі більше", "більшою мірою"],
        "менше": ["меншою мірою", "не так багато", "менш"],
        "точно": ["безумовно", "напевно", "безсумнівно"],
        "приблизно": ["близько", "орієнтовно", "десь"],
        "завжди": ["постійно", "щоразу", "незмінно"],
        "ніколи": ["жодного разу", "в жодному разі", "зроду"],
        "іноді": ["часом", "інколи", "подеколи"],
        "раніше": ["до того", "перед цим", "свого часу"],
        "пізніше": ["потім", "згодом", "далі"],
        "відразу": ["одразу", "миттю", "негайно"],
        "вже": ["на цей момент", "на цю пору", "уже"],
        "ще": ["досі", "поки що", "все ще"],
        "здатний": ["спроможний", "готовий", "може"],
        "здатна": ["спроможна", "готова", "може"],
        "необхідний": ["потрібний", "обов'язковий", "конче потрібний"],
        "необхідна": ["потрібна", "обов'язкова", "конче потрібна"],
        "конкретний": ["певний", "визначений", "чіткий"],
        "конкретна": ["певна", "визначена", "чітка"],
        "загальний": ["спільний", "цілісний", "глобальний"],
        "загальна": ["спільна", "цілісна", "глобальна"],
        "сучасний": ["теперішній", "актуальний", "нинішній"],
        "сучасна": ["теперішня", "актуальна", "нинішня"],
        "типовий": ["характерний", "звичайний", "класичний"],
        "типова": ["характерна", "звичайна", "класична"],
        "реальний": ["справжній", "дійсний", "фактичний"],
        "реальна": ["справжня", "дійсна", "фактична"],
        "реально": ["справді", "дійсно", "фактично"],
        "думати": ["вважати", "гадати", "міркувати"],
        "думає": ["вважає", "гадає", "міркує"],
        "знати": ["розуміти", "усвідомлювати", "бути в курсі"],
        "знає": ["розуміє", "усвідомлює", "в курсі"],
        "робити": ["виконувати", "здійснювати", "чинити"],
        "робить": ["виконує", "здійснює", "чинить"],
        "говорити": ["казати", "стверджувати", "зазначати"],
        "говорить": ["каже", "стверджує", "зазначає"],
        "бачити": ["спостерігати", "помічати", "виявляти"],
        "бачить": ["спостерігає", "помічає", "виявляє"],
        "розуміти": ["усвідомлювати", "збагнути", "осягати"],
        "розуміє": ["усвідомлює", "збагнув", "осягає"],
        "починати": ["розпочинати", "стартувати", "братися"],
        "починає": ["розпочинає", "стартує", "береться"],
        "закінчувати": ["завершувати", "доводити до кінця", "фіналізувати"],
        "закінчує": ["завершує", "доводить до кінця", "фіналізує"],
        "давати": ["надавати", "забезпечувати", "постачати"],
        "дає": ["надає", "забезпечує", "постачає"],
        "брати": ["використовувати", "застосовувати", "залучати"],
        "бере": ["використовує", "застосовує", "залучає"],
        "розвиток": ["зростання", "прогрес", "еволюція"],
        "система": ["механізм", "структура", "комплекс"],
        "аналіз": ["дослідження", "розбір", "огляд"],
        "рівень": ["ступінь", "міра", "щабель"],
        "якість": ["рівень", "клас", "ґатунок"],
        "кількість": ["обсяг", "число", "маса"],
        "ситуація": ["обстановка", "стан справ", "становище"],
        "інформація": ["дані", "відомості", "факти"],
        "досвід": ["практика", "навички", "багаж знань"],
        "питання": ["тема", "аспект", "момент"],
        "область": ["сфера", "галузь", "царина"],
        "умова": ["передумова", "вимога", "обставина"],
        "частина": ["елемент", "складова", "компонент"],
        "група": ["команда", "колектив", "об'єднання"],
        "період": ["час", "етап", "проміжок"],
        "причина": ["чинник", "привід", "підстава"],
        "вплив": ["дія", "ефект", "тиск"],
        "увага": ["інтерес", "фокус", "акцент"],
        "зміна": ["перетворення", "трансформація", "корекція"],
        "завдання": ["задача", "доручення", "місія"],
        "рішення": ["вирішення", "відповідь", "вихід"],
        "успіх": ["досягнення", "перемога", "здобуток"],
        "ідея": ["задум", "концепція", "думка"],
        "факт": ["обставина", "дійсність", "реалія"],
        "дія": ["вчинок", "крок", "акт"],
        "ціна": ["вартість", "коштовність", "плата"],
        "значення": ["сенс", "роль", "вага"],
        "вибір": ["рішення", "альтернатива", "опція"],
        "різниця": ["відмінність", "зазор", "невідповідність"],
        "проект": ["планування", "ініціатива", "програма"],
        "підхід": ["метод", "стратегія", "тактика"],
        "набір": ["комплект", "пакет", "добірка"],
        "ресурс": ["запас", "джерело", "засіб"],
        "висновок": ["підсумок", "резюме", "узагальнення"],
        # === v0.12.0 expansion ===
        "шукати": ["розшукувати", "відшуковувати", "вишукувати"],
        "шукає": ["розшукує", "відшуковує", "вишукує"],
        "вважати": ["гадати", "міркувати", "мати на увазі"],
        "відчувати": ["переживати", "сприймати", "чути"],
        "відчуває": ["переживає", "сприймає", "чує"],
        "пропонувати": ["радити", "висувати", "рекомендувати"],
        "пропонує": ["радить", "висуває", "рекомендує"],
        "залишати": ["лишати", "покидати", "полишати"],
        "залишає": ["лишає", "покидає", "полишає"],
        "вирішувати": ["розв'язувати", "долати", "залагоджувати"],
        "вирішує": ["розв'язує", "долає", "залагоджує"],
        "підтримувати": ["допомагати", "сприяти", "берегти"],
        "підтримує": ["допомагає", "сприяє", "береже"],
        "зберігати": ["тримати", "утримувати", "беречи"],
        "зберігає": ["тримає", "утримує", "береже"],
        "обирати": ["вибирати", "добирати", "відбирати"],
        "обирає": ["вибирає", "добирає", "відбирає"],
        "переконувати": ["доводити", "запевняти", "умовляти"],
        "переконує": ["доводить", "запевняє", "умовляє"],
        "зростати": ["збільшуватися", "посилюватися", "нарощуватися"],
        "зростає": ["збільшується", "посилюється", "нарощується"],
        "зменшувати": ["скорочувати", "понижувати", "звужувати"],
        "зменшує": ["скорочує", "понижує", "звужує"],
        "впливати": ["діяти", "позначатися", "відбиватися"],
        "впливає": ["діє", "позначається", "відбивається"],
        "досягати": ["здобувати", "набувати", "виборювати"],
        "досягає": ["здобуває", "набуває", "виборює"],
        "забувати": ["випускати з пам'яті", "не тямити", "нехтувати"],
        "забуває": ["випускає з пам'яті", "не тямить", "нехтує"],
        "чекати": ["очікувати", "сподіватися", "виглядати"],
        "чекає": ["очікує", "сподівається", "виглядає"],
        "відповідь": ["реакція", "репліка", "відгук"],
        "помилка": ["хиба", "огріх", "недолік"],
        "користь": ["вигода", "зиск", "перевага"],
        "праця": ["робота", "діяльність", "зусилля"],
        "порада": ["рада", "рекомендація", "підказка"],
        "перевага": ["плюс", "козир", "сильна сторона"],
        "недолік": ["вада", "хиба", "мінус"],
        "зусилля": ["старання", "намагання", "спроби"],
        "довіра": ["віра", "упевненість", "надія"],
        "загроза": ["небезпека", "ризик", "виклик"],
        "стан": ["становище", "положення", "обстановка"],
        "напрямок": ["курс", "вектор", "шлях"],
        "межа": ["кордон", "грань", "край"],
        "суть": ["зміст", "сутність", "головне"],
        "крок": ["захід", "вчинок", "рух"],
        "правило": ["принцип", "норма", "закон"],
        "приклад": ["зразок", "випадок", "ілюстрація"],
        "місце": ["точка", "позиція", "локація"],
        "швидкий": ["стрімкий", "прудкий", "хуткий"],
        "швидка": ["стрімка", "прудка", "хутка"],
        "повільний": ["неквапний", "млявий", "в'ялий"],
        "повільна": ["неквапна", "млява", "в'яла"],
        "яскравий": ["виразний", "помітний", "барвистий"],
        "яскрава": ["виразна", "помітна", "барвиста"],
        "темний": ["похмурий", "тьмяний", "непроглядний"],
        "світлий": ["ясний", "сяйний", "чистий"],
        "тихий": ["безшумний", "спокійний", "лагідний"],
        "тиха": ["безшумна", "спокійна", "лагідна"],
        "глибокий": ["ґрунтовний", "вдумливий", "детальний"],
        "глибока": ["ґрунтовна", "вдумлива", "детальна"],
        "широкий": ["обширний", "масштабний", "розлогий"],
        "широка": ["обширна", "масштабна", "розлога"],
        "вузький": ["тісний", "обмежений", "звужений"],
        "вузька": ["тісна", "обмежена", "звужена"],
        "високий": ["піднесений", "чималий", "значний"],
        "висока": ["піднесена", "чимала", "значна"],
        "низький": ["невисокий", "малий", "незначний"],
        "низька": ["невисока", "мала", "незначна"],
        "довгий": ["тривалий", "затяжний", "подовжений"],
        "довга": ["тривала", "затяжна", "подовжена"],
        "короткий": ["нетривалий", "стислий", "лаконічний"],
        "коротка": ["нетривала", "стисла", "лаконічна"],
        "чистий": ["прозорий", "незаплямований", "бездоганний"],
        "чиста": ["прозора", "незаплямована", "бездоганна"],
        "спокійний": ["врівноважений", "тихий", "незворушний"],
        "спокійна": ["врівноважена", "тиха", "незворушна"],
    },

    # Альтернативні початки речень
    "sentence_starters": {
        "Це": ["Такий підхід", "Подібне", "Воно", "Все це"],
        "Він": ["Той", "Ця людина", "Фахівець"],
        "Вона": ["Та", "Ця", "Остання"],
        "Вони": ["Ті", "Усі вони", "Ці люди"],
        "Ми": ["Наша команда", "Усі ми", "Команда"],
        "В": ["При", "На", "Серед"],
        "На": ["При", "В", "Для"],
        "Для": ["Заради", "Задля", "Щоб"],
        "При": ["У разі", "Коли", "Якщо"],
        "Також": ["Ще", "На додаток", "Плюс до цього"],
        # === v0.11.0 massive expansion ===
        "Цей": ["Такий", "Подібний", "Той"],
        "Ця": ["Така", "Подібна", "Та"],
        "Ці": ["Такі", "Подібні", "Ті"],
        "Той": ["Цей", "Такий", "Зазначений"],
        "Та": ["Ця", "Така", "Зазначена"],
        "Ті": ["Ці", "Такі", "Зазначені"],
        "Кожен": ["Будь-який", "Всякий", "Кожний окремий"],
        "Кожна": ["Будь-яка", "Всяка", "Кожна окрема"],
        "Усі": ["Кожен", "Будь-який", "Всі без винятку"],
        "Після": ["Вслід за", "По закінченні", "Коли"],
        "Перед": ["До", "Перш ніж", "Напередодні"],
        "Коли": ["Як тільки", "У той момент коли", "Щойно"],
        "Якщо": ["У разі", "Коли", "За умови"],
        "Хоча": ["Незважаючи на те що", "Хай", "Навіть при тому що"],
        "Але": ["Однак", "Втім", "Зате"],
        "І": ["Та й", "Плюс", "На додаток"],
        "Тому": ["Відтак", "Ось чому", "Через це"],
        "Спочатку": ["Для початку", "Передусім", "Першим ділом"],
        "Потім": ["Далі", "Після цього", "Згодом"],
        "Далі": ["Потім", "Згодом", "Слідом"],
        "Втім": ["Хоча", "Щоправда", "Але"],
        "Звісно": ["Зрозуміло", "Ясна річ", "Безумовно"],
        "Очевидно": ["Ясно", "Зрозуміло", "Видно"],
        "Можливо": ["Мабуть", "Імовірно", "Вірогідно"],
        "Сьогодні": ["Наразі", "У наші дні", "Нині"],
        "Тут": ["Ось тут", "У цьому місці", "Саме тут"],
        # === v0.12.0 expansion ===
        "Зрозуміло": ["Ясна річ", "Звісно", "Безперечно"],
        "Мабуть": ["Напевно", "Либонь", "Видно"],
        "Зазвичай": ["Як правило", "Найчастіше", "Здебільшого"],
        "Безперечно": ["Без сумніву", "Поза сумнівом", "Однозначно"],
        "Зважмо": ["Врахуймо", "Зверніть увагу", "Подивимось"],
        "Приміром": ["Наприклад", "Скажімо", "Хоча б"],
        "Насправді": ["По правді кажучи", "Якщо чесно", "Насправжки"],
        "Інакше": ["А то", "Бо інакше", "У протилежному разі"],
        "Крім": ["Окрім", "За винятком", "Не рахуючи"],
        "Завдяки": ["Через", "За допомогою", "Саме через"],
        # --- v0.27.0 expansion ---
        "Безсумнівно": ["Безперечно", "Без двох думок", "Однозначно"],
        "Зрештою": ["Наприкінці", "Наостанок", "Врешті"],
        "Натомість": ["Зате", "Замість того", "А от"],
        "Попри": ["Незважаючи на", "Всупереч", "Хоча"],
        "Нерідко": ["Часто", "Не раз", "Буває"],
        "Подеколи": ["Іноді", "Час від часу", "Буває"],
        "Загальновідомо": ["Усім відомо", "Ні для кого не секрет", "Як відомо"],
        "Однозначно": ["Безперечно", "Точно", "Без сумніву"],
        "Показово": ["Характерно", "Промовисто", "Красномовно"],
        "Принагідно": ["До речі", "Між іншим", "До слова"],
        "Власне": ["По суті", "Якщо точніше", "Справді"],
        "Вочевидь": ["Схоже", "Мабуть", "Напевно"],
        "Нещодавно": ["Останнім часом", "Днями", "Не так давно"],
        "Раніше": ["Колись", "Перед тим", "До того"],
        "Зрозуміло": ["Ясна річ", "Звісно", "Безперечно"],
        "Упродовж": ["Протягом", "У ході", "Під час"],
        "Невдовзі": ["Скоро", "Незабаром", "От-от"],
        "Водночас": ["Одночасно", "Паралельно", "Поряд з цим"],
        "Насамперед": ["Передусім", "Перш за все", "Головне"],
        "Загалом": ["У цілому", "Якщо коротко", "Взагалі"],
        "Типово": ["Зазвичай", "Як правило", "Здебільшого"],
    },

    # Розмовні маркери для chat/web профілів
    "colloquial_markers": [
        "до речі",
        "до слова",
        "насправді",
        "по суті",
        "загалом",
        "між іншим",
        "власне",
        "простіше кажучи",
        "грубо кажучи",
        "якщо коротко",
        # === v0.11.0 massive expansion ===
        "без перебільшень",
        "будьмо чесні",
        "взагалі",
        "взагалі-то",
        "ось у чому річ",
        "головне тут",
        "іншими словами",
        "якщо говорити прямо",
        "якщо подумати",
        "якщо розібратися",
        "є така думка",
        "зауважу",
        "знаєте що",
        "і ось що цікаво",
        "якщо чесно",
        "цікаво",
        "наприклад",
        "коротше кажучи",
        "любопитно",
        "між нами",
        "можна сказати",
        "на ділі",
        "на мій погляд",
        "треба сказати",
        "треба визнати",
        "не буду приховувати",
        "не секрет",
        "ну от",
        "ну і",
        "однозначно",
        "виявляється",
        "відверто кажучи",
        "по-моєму",
        "по правді кажучи",
        "по факту",
        "поклавши руку на серце",
        "прямо скажу",
        "скажімо так",
        "скажу чесно",
        "слухайте",
        "дивіться",
        "власне кажучи",
        "варто зауважити",
        "суть у тому",
        "так чи інакше",
        "тут важливо зрозуміти",
        "факт у тому",
        "чесно кажучи",
        "що важливо",
        "що цікаво",
        "що характерно",
        # === v0.12.0 expansion ===
        "знаєте",
        "розумієте",
        "бачте",
        "от саме",
        "ну як сказати",
        "от і виходить",
        "от я і кажу",
        "можете уявити",
        "скажу вам",
        "повірте",
        "самі подумайте",
        "от вам і відповідь",
        "не повірите",
        "а що поробиш",
        "та годі вже",
        "ну ви зрозуміли",
        "та й годі",
        "хто б міг подумати",
        "а от і ні",
        "от у чому фішка",
        "якщо по-простому",
        "як кажуть",
        "по-людськи кажучи",
        "чесне слово",
        "от так от",
        # --- v0.27.0 expansion ---
        "якщо вдуматися",
        "для ясності",
        "одним словом",
        "як на мене",
        "як бачимо",
        "не приховую",
        "ну що тут скажеш",
        "давайте будемо чесні",
        "якщо без жартів",
        "от де штука",
        "як би це сказати",
        "я б сказав",
        "при всьому цьому",
        "щиро скажу",
    ],

    # Абревіатури
    "abbreviations": [
        "р", "рр", "т.д", "т.п", "т.ч", "і т.д", "і т.п", "ін",
        "пр", "напр", "ред", "рис", "табл", "стор", "див",
        "обл", "грн", "тис", "млн", "млрд",
        "кв", "км", "м", "мм", "см", "кг", "мг", "л", "мл",
        "с", "хв", "год", "ім", "акад", "проф", "доц",
        # === v0.11.0 massive expansion ===
        "м-н", "м-р", "вул", "пл", "просп", "б-р", "пров",
        "п-к", "мікрор-н", "корп", "буд",
        "докт", "канд", "інж", "арх", "асп",
        "ст", "мол", "старш", "молодш",
        "п.", "пн", "вт", "ср", "чт", "пт", "сб", "нд",
        "січ", "лют", "бер", "квіт", "трав", "черв",
        "лип", "серп", "вер", "жовт", "листоп", "груд",
        "міст", "с-ще", "розд", "відд", "упр",
        "дир", "заст", "нач", "гол", "голова",
        "секр", "бухг", "екон", "юрист",
        "коп", "га", "цтн", "тонн",
        "цейнт", "кал", "темп",
        "макс", "мін", "середн", "прибл",
        "оф", "неоф", "держ", "прив",
        "орг", "техн", "мед", "пед",
        "філос", "політ", "№",
    ],

    # Бустери перплексії (рідкісні/незвичайні фрази для підвищення перплексії)
    "perplexity_boosters": [
        "як не крути", "так чи інакше", "хоч як би там було",
        "nolens volens", "de facto", "ipso facto",
        "парадоксально", "цікаво", "іронічно",
        "загалом і вцілому", "по великому рахунку",
        "поклавши руку на серце", "чого вже там",
        "будьмо чесними", "треба визнати", "гріх нарікати",
        "не без підстав", "до слова кажучи",
        "у певному сенсі", "до певної міри",
        "об'єктивно кажучи", "всупереч очікуванням",
        "як не дивно", "при всьому при тому",        # === v0.11.0 massive expansion ===
        "а відтак", "без зайвих слів",
        "будь що буде", "в певному сенсі",
        "в кінці-кінців", "вірите ви чи ні",
        "ось де собака зарита", "ось що я вам скажу",
        "говорячи начистоту", "грубо прикидаючи",
        "якщо розібратися по-хорошому",
        "і ось тут-то", "і ось що примітно",
        "до вашого відому", "як бачите",
        "як водиться", "як мінімум",
        "як на зло", "як показала практика",
        "між нами кажучи", "м'яко висловлюючись",
        "на повірку", "треба гадати",
        "не в образу буде сказано", "не мудруючи лукаво",
        "нічого дивного", "по здоровому роздуму",
        "по совісті кажучи", "правди ради",
        "при ближчому розгляді", "при всьому бажанні",
        "ради справедливості", "ризикну припустити",
        "сказати по честі", "слід визнати",
        "строго між нами", "хочеш не хочеш",
        "це до слова",
        # === v0.12.0 expansion ===
        "а втім, судіть самі", "без перебору",
        "вірте на слово", "гадаю не помилюсь",
        "дивна річ", "до певної міри правда",
        "є підстави вважати", "з власного досвіду скажу",
        "за великим рахунком", "за збігом обставин",
        "за здоровим глуздом", "зовсім не жарт",
        "і це ще не все", "коли добре подумати",
        "кожному своє", "між двох вогнів",
        "на превеликий жаль", "не від доброго життя",
        "не те слово", "ніхто не заперечить",
        "палка в двох кінцях", "при всій повазі",
        "самі розумієте", "скажу без обиняків",
        "схоже на правду", "хоч як не крути",
        "щиро кажучи", "як мовиться",
        "як то кажуть", "от де правда",
        # --- v0.27.0 expansion ---
        "що тут казати", "от де штука",
        "даруйте за прямоту", "не для протоколу",
        "чисто теоретично", "якщо без лукавства",
        "між іншим кажучи", "ну що ж",
        "вірите чи ні", "не жартую",
        "у буквальному сенсі", "без жодного перебільшення",
        "щось мені підказує", "на честь сказати",
        "тут уже нікуди дітися", "от вам і весь казус",
        "як то мовиться", "хоч вір хоч не вір",
        "без обиняків кажучи", "якщо вдуматися",
        "не побоюсь цього слова", "при всьому при цьому",
        "із цікавості зазначу", "ось у чому сіль",
        "отож-бо й воно", "як не верти",
        "не буду мудрувати", "якщо брати ширше",
        "прямо скажемо", "тут уже без варіантів",
        "от тобі й маєш", "хай там як",
        "нема чого лукавити", "до слова сказати",
        "оце так штука", "ну як тут бути",
        "якщо покласти руку на серце", "от тобі на",
    ],

    # Цільові метрики за профілями
    "profile_targets": {
        "chat": {"avg_sentence_len": (8, 18), "max_sentence_len": 30},
        "web": {"avg_sentence_len": (10, 22), "max_sentence_len": 40},
        "seo": {"avg_sentence_len": (12, 25), "max_sentence_len": 45},
        "docs": {"avg_sentence_len": (12, 28), "max_sentence_len": 50},
        "formal": {"avg_sentence_len": (15, 30), "max_sentence_len": 55},
    },

    # Сполучники для склеювання коротких речень
    "conjunctions": ["і", "а", "але", "та", "або", "причому", "хоча"],

    # Сполучники для розбиття довгих речень
    "split_conjunctions": [
        ", і ", ", а ", ", але ", ", однак ", ", хоча ",
        ", причому ", ", при цьому ", ", тому ",
        ", що ", "; ", " — ",
        # === v0.11.0 massive expansion ===
        ", тому що ", ", оскільки ", ", адже ",
        ", якщо ", ", коли ", ", поки ",
        ", хоча би ", ", незважаючи на ", ", замість ",
        ", після чого ", ", в результаті чого ",
        ", тоді як ", ", адже ", ", бо ",
        ", тобто ", ", а саме ", ", інакше ",
        ", отже ", ", значить ", ", виходить ",
        " – ",
    ],
}



"""Content Spinner — перезапись и перемешивание текста.

Генерирует уникальные версии текста:
- Spintax формат {вариант1|вариант2|вариант3}
- Многоуровневый спиннинг (слово/фраза/предложение/абзац)
- Уникализация с контролем качества
"""

from __future__ import annotations

import logging
import random
import re
from dataclasses import dataclass

from texthumanize.morphology import get_morphology

logger = logging.getLogger(__name__)

@dataclass
class SpinResult:
    """Результат спиннинга."""

    original: str
    spun: str
    spintax: str  # spintax формат
    uniqueness: float  # 0..1, отличие от оригинала
    variants_count: int  # сколько вариантов можно сгенерировать


# ═══════════════════════════════════════════════════════════════
#  СЛОВАРИ СИНОНИМОВ ДЛЯ СПИННИНГА
# ═══════════════════════════════════════════════════════════════

_SPIN_SYNONYMS = {
    "en": {
        # Verbs
        "use": ["utilize", "employ", "apply", "leverage", "make use of"],
        "make": ["create", "produce", "generate", "build", "construct"],
        "get": ["obtain", "acquire", "receive", "gain", "secure"],
        "show": ["demonstrate", "display", "reveal", "illustrate", "present"],
        "help": ["assist", "support", "aid", "facilitate", "enable"],
        "need": ["require", "necessitate", "demand", "call for"],
        "think": ["believe", "consider", "regard", "suppose", "reckon"],
        "give": ["provide", "offer", "supply", "deliver", "present"],
        "find": ["discover", "locate", "identify", "uncover", "detect"],
        "know": ["understand", "recognize", "realize", "comprehend"],
        "want": ["desire", "wish", "seek", "aim for"],
        "try": ["attempt", "endeavor", "strive", "seek to"],
        "start": ["begin", "commence", "initiate", "launch"],
        "end": ["finish", "conclude", "complete", "terminate"],
        "change": ["modify", "alter", "adjust", "transform"],
        "improve": ["enhance", "upgrade", "boost", "optimize"],
        "reduce": ["decrease", "diminish", "lower", "minimize"],
        "increase": ["raise", "elevate", "boost", "amplify"],
        "include": ["encompass", "incorporate", "comprise", "contain"],
        "develop": ["create", "build", "design", "establish"],
        "explain": ["clarify", "describe", "elaborate", "outline"],
        "keep": ["maintain", "retain", "preserve", "hold"],
        "provide": ["supply", "furnish", "deliver", "offer", "grant"],
        "allow": ["permit", "enable", "let", "authorize"],
        "suggest": ["propose", "recommend", "advise", "imply"],
        "handle": ["manage", "deal with", "address", "tackle"],
        "ensure": ["guarantee", "confirm", "verify", "make sure"],
        "achieve": ["accomplish", "attain", "reach", "realize"],
        "remove": ["eliminate", "delete", "discard", "erase"],
        "avoid": ["prevent", "steer clear of", "evade", "bypass"],
        # Adjectives
        "important": ["crucial", "vital", "essential", "significant", "critical"],
        "good": ["excellent", "outstanding", "great", "superior", "fine"],
        "bad": ["poor", "inferior", "substandard", "inadequate"],
        "big": ["large", "substantial", "considerable", "significant"],
        "small": ["tiny", "minor", "slight", "modest", "compact"],
        "new": ["novel", "recent", "fresh", "modern", "latest"],
        "old": ["previous", "former", "traditional", "established"],
        "fast": ["rapid", "quick", "swift", "speedy", "prompt"],
        "easy": ["simple", "straightforward", "effortless", "uncomplicated"],
        "hard": ["difficult", "challenging", "complex", "demanding"],
        "clear": ["obvious", "evident", "apparent", "transparent"],
        "different": ["various", "diverse", "distinct", "alternative"],
        "main": ["primary", "principal", "chief", "key", "central"],
        "common": ["widespread", "frequent", "typical", "prevalent"],
        "specific": ["particular", "precise", "exact", "definite"],
        "possible": ["feasible", "viable", "achievable", "potential"],
        "necessary": ["essential", "required", "needed", "indispensable"],
        "useful": ["helpful", "beneficial", "valuable", "practical"],
        # Adverbs
        "also": ["additionally", "furthermore", "moreover", "besides"],
        "however": ["nevertheless", "nonetheless", "yet", "still"],
        "therefore": ["consequently", "thus", "hence", "accordingly"],
        "often": ["frequently", "regularly", "commonly", "repeatedly"],
        "usually": ["typically", "generally", "normally", "commonly"],
        "quickly": ["rapidly", "swiftly", "promptly", "speedily"],
        "very": ["extremely", "highly", "remarkably", "exceptionally"],
        "especially": ["particularly", "notably", "chiefly", "above all"],
        "actually": ["in fact", "really", "indeed", "as a matter of fact"],
        "recently": ["lately", "of late", "not long ago", "just now"],
        # Connectors
        "because": ["since", "as", "due to the fact that", "given that"],
        "but": ["however", "yet", "nevertheless", "on the other hand"],
        "and": ["as well as", "along with", "in addition to", "plus"],
    },
    "ru": {
        # Глаголы
        "использовать": ["применять", "задействовать", "употреблять"],
        "делать": ["выполнять", "осуществлять", "производить", "совершать"],
        "получать": ["обретать", "приобретать", "добывать"],
        "показывать": ["демонстрировать", "отображать", "иллюстрировать"],
        "помогать": ["содействовать", "способствовать", "поддерживать"],
        "начинать": ["приступать", "стартовать", "инициировать"],
        "заканчивать": ["завершать", "оканчивать", "финализировать"],
        "менять": ["изменять", "модифицировать", "трансформировать"],
        "улучшать": ["совершенствовать", "оптимизировать", "повышать"],
        "увеличивать": ["повышать", "наращивать", "усиливать"],
        "уменьшать": ["сокращать", "снижать", "минимизировать"],
        "создавать": ["формировать", "разрабатывать", "конструировать"],
        "думать": ["полагать", "считать", "рассуждать"],
        "говорить": ["утверждать", "заявлять", "высказывать", "сообщать"],
        "видеть": ["наблюдать", "замечать", "обнаруживать", "различать"],
        "давать": ["предоставлять", "обеспечивать", "вручать"],
        "работать": ["трудиться", "функционировать", "действовать"],
        "решать": ["определять", "устранять", "разрешать", "урегулировать"],
        "предлагать": ["рекомендовать", "советовать", "выдвигать"],
        "проверять": ["контролировать", "инспектировать", "анализировать"],
        "выбирать": ["отбирать", "подбирать", "определять", "предпочитать"],
        "описывать": ["характеризовать", "изображать", "обрисовывать"],
        "определять": ["устанавливать", "выявлять", "фиксировать"],
        "поддерживать": ["обеспечивать", "сохранять", "содействовать"],
        "понимать": ["осознавать", "осмысливать", "постигать"],
        "вести": ["руководить", "направлять", "управлять"],
        "требовать": ["нуждаться", "предполагать", "запрашивать"],
        "включать": ["охватывать", "содержать", "объединять"],
        "обеспечивать": ["гарантировать", "предоставлять", "снабжать"],
        "объяснять": ["разъяснять", "пояснять", "толковать", "раскрывать"],
        "избегать": ["обходить", "уклоняться", "сторониться"],
        "достигать": ["добиваться", "обретать", "реализовывать"],
        "удалять": ["устранять", "убирать", "ликвидировать"],
        # Прилагательные
        "важный": ["существенный", "значимый", "ключевой", "принципиальный"],
        "хороший": ["отличный", "прекрасный", "качественный", "достойный"],
        "плохой": ["скверный", "некачественный", "неудачный"],
        "большой": ["крупный", "масштабный", "значительный", "солидный"],
        "маленький": ["небольшой", "компактный", "незначительный"],
        "новый": ["современный", "свежий", "актуальный", "недавний"],
        "быстрый": ["стремительный", "оперативный", "скоростной"],
        "разный": ["различный", "разнообразный", "многообразный"],
        "основной": ["главный", "ключевой", "центральный", "первостепенный"],
        "простой": ["несложный", "элементарный", "нехитрый", "доступный"],
        "сложный": ["трудный", "непростой", "затруднительный", "замысловатый"],
        "нужный": ["необходимый", "требуемый", "востребованный"],
        "полезный": ["ценный", "практичный", "продуктивный", "выгодный"],
        "возможный": ["вероятный", "допустимый", "реальный", "осуществимый"],
        "известный": ["знаменитый", "популярный", "признанный", "прославленный"],
        # Наречия
        "также": ["кроме того", "помимо этого", "вдобавок"],
        "однако": ["тем не менее", "впрочем", "вместе с тем"],
        "поэтому": ["следовательно", "таким образом", "вследствие этого"],
        "часто": ["нередко", "зачастую", "регулярно"],
        "обычно": ["как правило", "зачастую", "в большинстве случаев"],
        "очень": ["чрезвычайно", "крайне", "весьма", "исключительно"],
        "особенно": ["в особенности", "прежде всего", "в первую очередь"],
        "сначала": ["первоначально", "поначалу", "вначале", "прежде"],
        "иногда": ["порой", "временами", "изредка", "время от времени"],
        "почти": ["практически", "едва ли не", "фактически"],
    },
    "uk": {
        # Дієслова
        "використовувати": ["застосовувати", "вживати", "задіювати"],
        "робити": ["виконувати", "здійснювати", "чинити"],
        "отримувати": ["здобувати", "набувати", "одержувати"],
        "показувати": ["демонструвати", "відображати", "ілюструвати"],
        "допомагати": ["сприяти", "підтримувати", "підсобляти"],
        "починати": ["розпочинати", "стартувати", "ініціювати"],
        "закінчувати": ["завершувати", "фіналізувати"],
        "змінювати": ["модифікувати", "трансформувати", "перетворювати"],
        "покращувати": ["вдосконалювати", "оптимізувати", "підвищувати"],
        "говорити": ["стверджувати", "заявляти", "висловлювати", "повідомляти"],
        "бачити": ["спостерігати", "помічати", "виявляти", "розрізняти"],
        "давати": ["надавати", "забезпечувати", "вручати"],
        "працювати": ["трудитися", "функціонувати", "діяти"],
        "вирішувати": ["визначати", "усувати", "розв'язувати", "врегульовувати"],
        "пропонувати": ["рекомендувати", "радити", "висувати"],
        "перевіряти": ["контролювати", "інспектувати", "аналізувати"],
        "обирати": ["відбирати", "підбирати", "визначати", "віддавати перевагу"],
        "описувати": ["характеризувати", "зображувати", "окреслювати"],
        "визначати": ["встановлювати", "виявляти", "фіксувати"],
        "підтримувати": ["забезпечувати", "зберігати", "сприяти"],
        "розуміти": ["усвідомлювати", "осмислювати", "збагнути"],
        "вести": ["керувати", "спрямовувати", "управляти"],
        "вимагати": ["потребувати", "передбачати", "запитувати"],
        "включати": ["охоплювати", "містити", "об'єднувати"],
        "забезпечувати": ["гарантувати", "надавати", "постачати"],
        "пояснювати": ["роз'яснювати", "тлумачити", "розкривати"],
        "уникати": ["обходити", "ухилятися", "сторонитися"],
        "досягати": ["здобувати", "домагатися", "реалізовувати"],
        "видаляти": ["усувати", "прибирати", "ліквідовувати"],
        "створювати": ["формувати", "розробляти", "конструювати"],
        "думати": ["гадати", "вважати", "міркувати", "розмірковувати"],
        "збільшувати": ["підвищувати", "нарощувати", "посилювати"],
        "зменшувати": ["скорочувати", "знижувати", "мінімізувати"],
        # Прикметники
        "важливий": ["суттєвий", "значущий", "ключовий", "принциповий"],
        "добрий": ["чудовий", "прекрасний", "якісний", "гідний"],
        "поганий": ["невдалий", "неякісний", "кепський"],
        "великий": ["значний", "масштабний", "чималий", "солідний"],
        "малий": ["невеликий", "компактний", "незначний"],
        "новий": ["сучасний", "свіжий", "актуальний", "недавній"],
        "швидкий": ["стрімкий", "оперативний", "хуткий"],
        "основний": ["головний", "ключовий", "центральний", "першорядний"],
        "простий": ["нескладний", "елементарний", "нехитрий", "доступний"],
        "складний": ["важкий", "непростий", "скрутний", "заплутаний"],
        "потрібний": ["необхідний", "обов'язковий", "затребуваний"],
        "корисний": ["цінний", "практичний", "продуктивний", "вигідний"],
        "можливий": ["ймовірний", "допустимий", "реальний", "здійсненний"],
        "відомий": ["знаменитий", "популярний", "визнаний", "славетний"],
        "різний": ["різноманітний", "відмінний", "розмаїтий"],
        # Прислівники
        "також": ["крім того", "окрім цього", "на додаток"],
        "однак": ["проте", "тим не менш", "втім"],
        "тому": ["отже", "відтак", "внаслідок цього"],
        "часто": ["нерідко", "регулярно", "почасти"],
        "зазвичай": ["як правило", "здебільшого", "переважно"],
        "дуже": ["надзвичайно", "вкрай", "вельми", "винятково"],
        "особливо": ["передусім", "зокрема", "насамперед"],
        "спочатку": ["первісно", "спершу", "на початку", "раніше"],
        "іноді": ["часом", "подеколи", "зрідка", "час від часу"],
        "майже": ["практично", "мало не", "фактично"],
    },
}


class ContentSpinner:
    """Спиннер контента — генерация уникальных версий текста."""

    def __init__(
        self,
        lang: str = "en",
        seed: int | None = None,
        intensity: float = 0.5,
    ):
        """
        Args:
            lang: Язык текста.
            seed: Зерно RNG.
            intensity: 0..1, доля слов для замены.
        """
        self.lang = lang
        self.rng = random.Random(seed)
        self.intensity = intensity
        self.morph = get_morphology(lang)
        self._synonyms = _SPIN_SYNONYMS.get(lang, {})

    def spin(self, text: str) -> SpinResult:
        """Спиннинг текста — создание уникальной версии.

        Args:
            text: Исходный текст.

        Returns:
            SpinResult с уникальной версией и spintax.
        """
        spintax = self._generate_spintax(text)
        spun = self._resolve_spintax(spintax)
        uniqueness = self._calculate_uniqueness(text, spun)
        variants = self._count_variants(spintax)

        return SpinResult(
            original=text,
            spun=spun,
            spintax=spintax,
            uniqueness=uniqueness,
            variants_count=variants,
        )

    def generate_spintax(self, text: str) -> str:
        """Генерировать spintax-формат текста.

        Args:
            text: Исходный текст.

        Returns:
            Текст в формате spintax.
        """
        return self._generate_spintax(text)

    def resolve_spintax(self, spintax: str) -> str:
        """Развернуть spintax в один из вариантов.

        Args:
            spintax: Текст в формате {вариант1|вариант2|...}.

        Returns:
            Один случайный вариант.
        """
        return self._resolve_spintax(spintax)

    def generate_variants(self, text: str, count: int = 5) -> list[str]:
        """Генерировать несколько уникальных вариантов текста.

        Args:
            text: Исходный текст.
            count: Количество вариантов.

        Returns:
            Список уникальных версий.
        """
        spintax = self._generate_spintax(text)
        variants: list[str] = []
        seen: set[str] = set()

        max_attempts = count * 3
        for _ in range(max_attempts):
            if len(variants) >= count:
                break
            variant = self._resolve_spintax(spintax)
            if variant not in seen:
                seen.add(variant)
                variants.append(variant)

        return variants

    # ───────────────────────────────────────────────────────────
    #  PRIVATE
    # ───────────────────────────────────────────────────────────

    def _generate_spintax(self, text: str) -> str:
        """Сгенерировать spintax из обычного текста."""
        words = text.split()
        result: list[str] = []

        for word in words:
            # Извлекаем слово и пунктуацию
            clean = word.strip('.,;:!?"\'()[]{}')
            prefix = word[:word.index(clean)] if clean and clean in word else ""
            suffix = word[word.index(clean) + len(clean):] if clean and clean in word else ""

            if not clean:
                result.append(word)
                continue

            # Ищем синонимы
            lower = clean.lower()
            syns = self._synonyms.get(lower, [])

            # Fallback to massive synonym DB if local dict misses
            if not syns:
                try:
                    from texthumanize._synonym_db import SynonymDB
                    syns = SynonymDB().get(lower, self.lang)
                except Exception:
                    pass

            if not syns or self.rng.random() > self.intensity:
                result.append(word)
                continue

            # Создаём spintax варианты
            variants = [clean]
            for syn in syns[:4]:  # Максимум 4 синонима
                # Согласуем форму
                matched = self.morph.find_synonym_form(clean, syn)
                # Сохраняем регистр
                if clean[0].isupper():
                    matched = matched[0].upper() + matched[1:]
                if clean.isupper():
                    matched = matched.upper()
                variants.append(matched)

            # Убираем дубликаты сохраняя порядок
            seen: list[str] = []
            for v in variants:
                if v not in seen:
                    seen.append(v)
            variants = seen

            if len(variants) > 1:
                spintax_word = "{" + "|".join(variants) + "}"
                result.append(prefix + spintax_word + suffix)
            else:
                result.append(word)

        return " ".join(result)

    def _resolve_spintax(self, spintax: str) -> str:
        """Развернуть spintax, выбирая случайные варианты."""
        def resolve_match(m: re.Match) -> str:
            options = m.group(1).split("|")
            return str(self.rng.choice(options))

        # Многоуровневый spintax — разворачиваем изнутри
        result = spintax
        max_depth = 5
        for _ in range(max_depth):
            new_result = re.sub(r'\{([^{}]+)\}', resolve_match, result)
            if new_result == result:
                break
            result = new_result

        return result

    @staticmethod
    def _calculate_uniqueness(original: str, spun: str) -> float:
        """Рассчитать уникальность (1 - сходство)."""
        orig_words = original.lower().split()
        spun_words = spun.lower().split()

        if not orig_words:
            return 1.0

        # Считаем совпадающие слова в позициях
        matches = sum(
            1 for a, b in zip(orig_words, spun_words) if a == b
        )
        max_len = max(len(orig_words), len(spun_words))
        return 1.0 - matches / max_len

    @staticmethod
    def _count_variants(spintax: str) -> int:
        """Подсчитать количество возможных вариантов."""
        groups = re.findall(r'\{([^{}]+)\}', spintax)
        if not groups:
            return 1

        count = 1
        for group in groups:
            options = group.split("|")
            count *= len(options)
            if count > 1_000_000:
                return 1_000_000  # Cap

        return count


# ═══════════════════════════════════════════════════════════════
#  УДОБНЫЕ ФУНКЦИИ
# ═══════════════════════════════════════════════════════════════

def spin_text(
    text: str,
    lang: str = "en",
    intensity: float = 0.5,
    seed: int | None = None,
) -> str:
    """Спиннинг текста — создать уникальную версию."""
    spinner = ContentSpinner(lang=lang, seed=seed, intensity=intensity)
    return spinner.spin(text).spun


def generate_spintax(
    text: str,
    lang: str = "en",
    intensity: float = 0.5,
) -> str:
    """Преобразовать текст в spintax формат."""
    spinner = ContentSpinner(lang=lang, intensity=intensity)
    return spinner.generate_spintax(text)


def generate_variants(
    text: str,
    count: int = 5,
    lang: str = "en",
    intensity: float = 0.5,
) -> list[str]:
    """Сгенерировать несколько уникальных версий текста."""
    spinner = ContentSpinner(lang=lang, intensity=intensity)
    return spinner.generate_variants(text, count=count)



"""Утилиты TextHumanize."""

from __future__ import annotations

import logging
import random
from dataclasses import dataclass, field
from difflib import SequenceMatcher
from typing import Any, TypedDict

logger = logging.getLogger(__name__)

@dataclass
class HumanizeOptions:
    """Опции гуманизации текста."""

    lang: str = "auto"
    profile: str = "web"
    intensity: int = 60
    preserve: dict[str, Any] = field(default_factory=lambda: {
        "code_blocks": True,
        "urls": True,
        "emails": True,
        "hashtags": True,
        "mentions": True,
        "markdown": True,
        "html": True,
        "numbers": False,
        "brand_terms": [],
    })
    constraints: dict[str, Any] = field(default_factory=lambda: {
        "min_sentence_length": 3,
        "keep_keywords": [],
    })
    seed: int | None = None
    # Целевой стилистический отпечаток для имитации авторского стиля
    target_style: Any | None = None  # StylisticFingerprint, preset name (str), or None
    # Пользовательский словарь замен: {"слово": "замена"} или {"слово": ["вар1", "вар2"]}
    custom_dict: dict[str, str | list[str]] | None = None
    # OpenAI API key для LLM-assisted evasion в детектор-петле
    openai_api_key: str | None = None
    openai_model: str = "gpt-4o-mini"

    def __post_init__(self) -> None:
        if self.intensity < 0:
            self.intensity = 0
        elif self.intensity > 100:
            self.intensity = 100
        _VALID_PROFILES = (
            "chat", "web", "seo", "docs", "formal",
            "academic", "marketing", "social", "email",
        )
        if self.profile not in _VALID_PROFILES:
            raise ValueError(
                f"Неизвестный профиль: {self.profile}. "
                f"Доступны: {', '.join(_VALID_PROFILES)}"
            )


@dataclass
class HumanizeResult:
    """Результат гуманизации текста."""

    original: str
    text: str
    lang: str
    profile: str
    intensity: int
    changes: list[dict[str, str]] = field(default_factory=list)
    metrics_before: dict[str, Any] = field(default_factory=dict)
    metrics_after: dict[str, Any] = field(default_factory=dict)

    @property
    def change_ratio(self) -> float:
        """Доля изменений в тексте (0..1).

        Использует SequenceMatcher для корректного сравнения —
        вставка/удаление одного слова не сдвигает все позиции.
        """
        if not self.original:
            return 0.0
        orig_words = self.original.split()
        new_words = self.text.split()
        if not orig_words:
            return 0.0
        matcher = SequenceMatcher(None, orig_words, new_words)
        return min(1.0 - matcher.ratio(), 1.0)

    @property
    def similarity(self) -> float:
        """Jaccard-подобие оригинала и результата (0..1).

        1.0 = идентичные тексты, 0.0 = полностью разные.
        """
        if not self.original or not self.text:
            return 1.0 if self.original == self.text else 0.0
        orig_set = set(self.original.lower().split())
        new_set = set(self.text.lower().split())
        if not orig_set and not new_set:
            return 1.0
        intersection = orig_set & new_set
        union = orig_set | new_set
        return len(intersection) / len(union) if union else 1.0

    @property
    def quality_score(self) -> float:
        """Общий балл качества обработки (0..1).

        Учитывает баланс между достаточным изменением текста
        и сохранением смысла (similarity). Идеал: ~0.75-0.90.
        """
        sim = self.similarity
        change = self.change_ratio
        # Штраф за слишком малые или слишком большие изменения
        if change < 0.01:
            # Текст не изменился — проверяем, нужны ли были изменения
            # Если similarity = 1.0, значит текст вернулся без изменений;
            # для уже естественных текстов это может быть желательно
            ai_before = self.metrics_before.get("artificiality_score", 50)
            if ai_before < 15:
                return 0.7  # Лёгкий текст — отсутствие изменений ОК
            return 0.3  # AI-текст без изменений — плохо
        if sim < 0.3:
            return 0.2  # Слишком сильно изменён — потеря смысла
        # Оптимальный диапазон change масштабируется от intensity:
        # intensity=20 → center=0.08, intensity=60 → center=0.18,
        # intensity=100 → center=0.30
        target_change = max(0.05, self.intensity / 100.0 * 0.30)
        change_score = 1.0 - abs(change - target_change) / 0.35
        change_score = max(0.0, min(1.0, change_score))
        return sim * 0.6 + change_score * 0.4


@dataclass
class AnalysisReport:
    """Отчёт анализа текста."""

    lang: str
    total_chars: int = 0
    total_words: int = 0
    total_sentences: int = 0
    avg_sentence_length: float = 0.0
    sentence_length_variance: float = 0.0
    bureaucratic_ratio: float = 0.0
    connector_ratio: float = 0.0
    repetition_score: float = 0.0
    typography_score: float = 0.0
    burstiness_score: float = 0.5
    artificiality_score: float = 0.0
    # Readability metrics
    flesch_kincaid_grade: float = 0.0
    coleman_liau_index: float = 0.0
    avg_word_length: float = 0.0
    avg_syllables_per_word: float = 0.0
    # N-gram perplexity metrics
    predictability_score: float = 0.0
    char_perplexity: float = 0.0
    vocabulary_richness: float = 0.0
    details: dict[str, Any] = field(default_factory=dict)


# ─── Профили ──────────────────────────────────────────────────

PROFILES = {
    "chat": {
        "description": "Живой разговорный стиль",
        "typography": {"dash": "-", "quotes": '"', "ellipsis": "..."},
        "decancel_intensity": 1.0,
        "structure_intensity": 1.0,
        "repetition_intensity": 0.8,
        "liveliness_intensity": 0.7,
        "target_sentence_len": (8, 18),
    },
    "web": {
        "description": "Нейтральный веб-контент",
        "typography": {"dash": "–", "quotes": '"', "ellipsis": "..."},
        "decancel_intensity": 0.8,
        "structure_intensity": 0.8,
        "repetition_intensity": 0.7,
        "liveliness_intensity": 0.1,
        "target_sentence_len": (10, 22),
    },
    "seo": {
        "description": "SEO-безопасный режим",
        "typography": {"dash": "–", "quotes": '"', "ellipsis": "..."},
        "decancel_intensity": 0.4,
        "structure_intensity": 0.5,
        "repetition_intensity": 0.3,
        "liveliness_intensity": 0.0,
        "target_sentence_len": (12, 25),
    },
    "docs": {
        "description": "Документация, технический стиль",
        "typography": {"dash": "—", "quotes": '"', "ellipsis": "…"},
        "decancel_intensity": 0.3,
        "structure_intensity": 0.4,
        "repetition_intensity": 0.5,
        "liveliness_intensity": 0.0,
        "target_sentence_len": (12, 28),
    },
    "formal": {
        "description": "Формальный стиль",
        "typography": {"dash": "—", "quotes": "«»", "ellipsis": "…"},
        "decancel_intensity": 0.2,
        "structure_intensity": 0.3,
        "repetition_intensity": 0.4,
        "liveliness_intensity": 0.0,
        "target_sentence_len": (15, 30),
    },
    "academic": {
        "description": "Академический / научный стиль",
        "typography": {"dash": "—", "quotes": "«»", "ellipsis": "…"},
        "decancel_intensity": 0.15,
        "structure_intensity": 0.25,
        "repetition_intensity": 0.3,
        "liveliness_intensity": 0.0,
        "target_sentence_len": (18, 35),
    },
    "marketing": {
        "description": "Маркетинговый / рекламный стиль",
        "typography": {"dash": "–", "quotes": '"', "ellipsis": "..."},
        "decancel_intensity": 0.9,
        "structure_intensity": 0.9,
        "repetition_intensity": 0.6,
        "liveliness_intensity": 0.8,
        "target_sentence_len": (6, 16),
    },
    "social": {
        "description": "Социальные сети / посты",
        "typography": {"dash": "-", "quotes": '"', "ellipsis": "..."},
        "decancel_intensity": 1.0,
        "structure_intensity": 1.0,
        "repetition_intensity": 0.7,
        "liveliness_intensity": 0.9,
        "target_sentence_len": (5, 14),
    },
    "email": {
        "description": "Деловая переписка",
        "typography": {"dash": "–", "quotes": '"', "ellipsis": "..."},
        "decancel_intensity": 0.5,
        "structure_intensity": 0.5,
        "repetition_intensity": 0.6,
        "liveliness_intensity": 0.1,
        "target_sentence_len": (10, 22),
    },
}


def get_profile(name: str) -> dict:
    """Получить конфигурацию профиля."""
    if name not in PROFILES:
        raise ValueError(f"Неизвестный профиль: {name}")
    return PROFILES[name]


def should_apply(intensity: int, profile_factor: float, threshold: float = 0.5) -> bool:
    """Решить, применять ли трансформацию на основе интенсивности и профиля.

    Args:
        intensity: Общая интенсивность (0-100).
        profile_factor: Множитель профиля (0.0-1.0).
        threshold: Порог срабатывания (0.0-1.0).

    Returns:
        True если трансформацию нужно применить.
    """
    effective = (intensity / 100.0) * profile_factor
    return effective >= threshold


def coin_flip(probability: float, rng: random.Random | None = None) -> bool:
    """Случайное решение с заданной вероятностью."""
    r = rng or random
    return r.random() < probability


def intensity_probability(intensity: int, profile_factor: float) -> float:
    """Вычислить вероятность применения трансформации."""
    return min((intensity / 100.0) * profile_factor, 1.0)


# ── TypedDicts for structured return types ────────────────


class DetectionMetrics(TypedDict, total=False):
    """Detailed per-metric scores from AI detection."""

    entropy: float
    burstiness: float
    vocabulary: float
    zipf: float
    stylometry: float
    ai_patterns: float
    punctuation: float
    coherence: float
    grammar_perfection: float
    opening_diversity: float
    readability_consistency: float
    rhythm: float
    perplexity: float
    discourse: float
    semantic_repetition: float
    entity_specificity: float
    voice: float
    topic_sentence: float


class DetectionReport(TypedDict, total=False):
    """Structured result of :func:`detect_ai`.

    Using ``total=False`` allows the dict to omit optional keys.
    """

    score: float
    heuristic_score: float
    combined_score: float
    stat_probability: float | None
    verdict: str
    confidence: float
    metrics: DetectionMetrics
    explanations: list[str]
    domain: str
    lang: str
    neural_probability: float | None
    neural_perplexity: float | None
    neural_perplexity_score: float | None
    neural_details: dict[str, object] | None



"""Языковой пакет: Итальянский (Italiano)."""

LANG_IT = {
    "code": "it",
    "name": "Italiano",

    "trigrams": [
        "che", "ell", "ion", "ent", "ato", "per", "ment", "azi",
        "con", "one", "zione", "sta", "ere", "non", "ess", "pre",
        "att", "ale", "nte", "ria", "ica", "ura", "ire", "gli",
        "pro", "tra", "ter", "tto", "res", "ost", "ono", "uto",
        "ita", "eri", "ova", "ali", "dei", "ati", "ori", "com",
    ],

    "stop_words": {
        "il", "lo", "la", "i", "gli", "le", "un", "uno", "una",
        "e", "o", "ma", "né", "che", "se", "non", "in",
        "di", "del", "della", "dei", "delle", "al", "alla",
        "con", "per", "da", "su", "tra", "fra",
        "io", "tu", "lui", "lei", "noi", "voi", "loro",
        "è", "sono", "ha", "hanno", "era", "essere", "avere",
        "questo", "questa", "questi", "queste", "quello", "quella",
        "mio", "mia", "tuo", "tua", "suo", "sua", "nostro",
        "più", "meno", "molto", "bene", "come", "dove",
        "tutto", "tutti", "tutta", "tutte", "altro", "altra",
        "già", "ancora", "anche", "solo", "ogni",
        "qui", "là", "quando", "mentre",
        "ci", "si", "mi", "ti", "vi", "ne",
    },

    "bureaucratic": {
        "implementare": ["mettere in atto", "realizzare", "applicare"],
        "ottimizzare": ["migliorare", "perfezionare", "affinare"],
        "finalizzare": ["concludere", "finire", "completare"],
        "concretizzare": ["realizzare", "mettere in pratica"],
        "generare": ["creare", "produrre", "dare"],
        "determinare": ["stabilire", "decidere", "fissare"],
        "significativo": ["notevole", "importante", "rilevante"],
        "fondamentale": ["essenziale", "basilare", "centrale"],
        "primario": ["principale", "primo", "essenziale"],
        "inerente": ["proprio", "legato", "connesso"],
        "esaustivo": ["completo", "dettagliato", "approfondito"],
        "innovativo": ["nuovo", "creativo", "originale"],
        "paradigmatico": ["esemplare", "tipico", "modello"],
        "preponderante": ["principale", "dominante", "maggiore"],
        "onnicomprensivo": ["completo", "totale", "globale"],
        "imprescindibile": ["necessario", "essenziale", "irrinunciabile"],
        "sistematico": ["regolare", "ordinato", "metodico"],
        "paradigma": ["modello", "schema", "quadro"],
        "olistico": ["globale", "complessivo", "d'insieme"],
        "catalizzare": ["stimolare", "accelerare", "innescare"],
        "corroborare": ["confermare", "avvalorare", "sostenere"],
        "concomitante": ["simultaneo", "parallelo", "congiunto"],
        "perenne": ["duraturo", "stabile", "continuo"],
        "trasversale": ["comune", "condiviso", "generale"],
        # === v0.10.0 ===
        "contestualizzare": ["situare", "inquadrare", "collocare"],
        "operativizzare": ["applicare", "mettere in opera", "eseguire"],
        "problematizzare": ["mettere in discussione", "questionare"],
        "dinamizzare": ["attivare", "rilanciare", "stimolare"],
        "razionalizzare": ["semplificare", "snellire", "riorganizzare"],
        "strutturare": ["organizzare", "ordinare", "impostare"],
        "veicolare": ["trasmettere", "diffondere", "portare"],
        "valorizzare": ["dare valore", "promuovere", "esaltare"],
        "esplicitare": ["chiarire", "precisare", "spiegare"],
        "formalizzare": ["ufficializzare", "codificare", "definire"],
        "dispiegare": ["schierare", "estendere", "distribuire"],
        "mobilitare": ["coinvolgere", "impegnare", "radunare"],
        "identificare": ["individuare", "riconoscere", "trovare"],
        "sintetizzare": ["riassumere", "condensare", "raccogliere"],
        "proattivo": ["anticipato", "previdente", "dinamico"],
        "multidisciplinare": ["vario", "diverso", "misto"],
        "ricorrente": ["frequente", "ripetuto", "abituale"],
        "tangibile": ["concreto", "reale", "palpabile"],
        "intrinseco": ["interno", "proprio", "naturale"],
        "preminente": ["superiore", "primo", "dominante"],
        "pertinente": ["adeguato", "appropriato", "rilevante"],
        "performante": ["efficace", "potente", "produttivo"],
        "strutturante": ["organizzativo", "fondativo", "chiave"],
        "impattante": ["incisivo", "forte", "significativo"],
        # === v0.11.0 massive expansion ===
        "delineare": ["tracciare", "descrivere", "definire"],
        "predisporre": ["preparare", "approntare", "organizzare"],
        "configurare": ["impostare", "organizzare", "disporre"],
        "articolare": ["suddividere", "organizzare", "comporre"],
        "elaborare": ["sviluppare", "produrre", "creare"],
        "formulare": ["esprimere", "proporre", "creare"],
        "perseguire": ["cercare", "inseguire", "mirare a"],
        "promuovere": ["sostenere", "incoraggiare", "lanciare"],
        "approfondire": ["esaminare", "studiare", "indagare"],
        "consolidare": ["rafforzare", "solidificare", "stabilizzare"],
        "evidenziare": ["mostrare", "sottolineare", "mettere in luce"],
        "specificare": ["precisare", "indicare", "definire"],
        "verificare": ["controllare", "accertare", "appurare"],
        "monitorare": ["controllare", "sorvegliare", "seguire"],
        "supervisionare": ["sorvegliare", "controllare", "dirigere"],
        "coordinare": ["organizzare", "gestire", "dirigere"],
        "pianificare": ["programmare", "progettare", "organizzare"],
        "progettare": ["pianificare", "ideare", "pensare"],
        "garantire": ["assicurare", "promettere", "dare certezza"],
        "facilitare": ["agevolare", "rendere facile", "aiutare"],
        "standardizzare": ["uniformare", "omologare", "regolarizzare"],
        "centralizzare": ["concentrare", "accentrare", "riunire"],
        "delegare": ["affidare", "demandare", "incaricare"],
        "integrare": ["unire", "incorporare", "completare"],
        "armonizzare": ["accordare", "bilanciare", "equilibrare"],
        "canalizzare": ["indirizzare", "convogliare", "dirigere"],
        "massimizzare": ["aumentare al massimo", "potenziare", "amplificare"],
        "minimizzare": ["ridurre", "limitare", "contenere"],
        "incentivare": ["stimolare", "incoraggiare", "spronare"],
        "sensibilizzare": ["rendere consapevole", "informare", "educare"],
        "finalizzato": ["mirato", "volto", "destinato"],
        "sussidiario": ["complementare", "secondario", "aggiuntivo"],
        "propedeutico": ["preparatorio", "introduttivo", "preliminare"],
        "consequenziale": ["logico", "coerente", "derivato"],
        "precipuo": ["proprio", "tipico", "specifico"],
        "afferente": ["relativo", "riguardante", "attinente"],
        "sovrintendere": ["dirigere", "sorvegliare", "controllare"],
        "demandare": ["affidare", "delegare", "trasferire"],
        "espletare": ["compiere", "eseguire", "svolgere"],
        "ottemperare": ["rispettare", "obbedire", "conformarsi"],
        "adempiere": ["compiere", "eseguire", "rispettare"],
        "coadiuvare": ["aiutare", "assistere", "collaborare"],
        "presiedere": ["dirigere", "guidare", "sovrintendere"],
        "dirimere": ["risolvere", "chiarire", "decidere"],
        "avallare": ["approvare", "confermare", "sostenere"],
        "stigmatizzare": ["criticare", "condannare", "biasimare"],
        "perorare": ["sostenere", "difendere", "invocare"],
        "annoverare": ["includere", "contare", "comprendere"],
        "compendioso": ["breve", "conciso", "sintetico"],
        "circostanziato": ["dettagliato", "preciso", "minuzioso"],
        "sostanziale": ["grande", "notevole", "consistente"],
        "preposto": ["incaricato", "addetto", "responsabile"],
        "contingente": ["temporaneo", "passeggero", "attuale"],
        "perentorio": ["deciso", "categorico", "definitivo"],
        "tassativo": ["obbligatorio", "rigido", "vincolante"],
        "proporzionale": ["adeguato", "commisurato", "equilibrato"],
        "preliminare": ["iniziale", "preparatorio", "preventivo"],
        "univoco": ["chiaro", "netto", "preciso"],
        "dirimente": ["decisivo", "risolutivo", "cruciale"],
        "impellente": ["urgente", "pressante", "incalzante"],
        "cogente": ["vincolante", "obbligatorio", "imperativo"],
        "pregresso": ["precedente", "passato", "anteriore"],
        "prodromico": ["iniziale", "preparatorio", "introduttivo"],
        "recepire": ["accogliere", "adottare", "fare proprio"],
        "disincentivare": ["scoraggiare", "frenare", "ostacolare"],
        "estrinsecare": ["manifestare", "esprimere", "mostrare"],
        "asserire": ["affermare", "dichiarare", "sostenere"],
        "postulare": ["presupporre", "assumere", "richiedere"],
        "enunciare": ["esporre", "dichiarare", "annunciare"],
        "denotare": ["indicare", "mostrare", "rivelare"],
        "sottendere": ["implicare", "presupporre", "comportare"],
        "contemplare": ["prevedere", "considerare", "includere"],
        "sussistere": ["esistere", "esserci", "permanere"],
        "ottemperanza": ["rispetto", "osservanza", "conformità"],
        "fattispecie": ["caso", "circostanza", "situazione"],
        "controparte": ["interlocutore", "corrispondente", "altra parte"],
        "prerogativa": ["diritto", "privilegio", "facoltà"],
        "peculiarità": ["caratteristica", "particolarità", "tratto"],
        "evenienza": ["possibilità", "caso", "circostanza"],
        "criticità": ["problema", "difficoltà", "punto debole"],
        "tempistica": ["tempi", "calendario", "scadenze"],
        "problematica": ["problema", "questione", "difficoltà"],
        "tematica": ["tema", "argomento", "questione"],
        "metodologia": ["metodo", "approccio", "tecnica"],
        "normativa": ["legge", "regola", "disciplina"],
        "potenzialità": ["possibilità", "capacità", "risorsa"],
        "operatività": ["funzionamento", "attività", "lavoro"],
        "fruibilità": ["accessibilità", "disponibilità", "utilizzo"],
        "sostenibilità": ["durabilità", "stabilità", "tenuta"],
        "interoperabilità": ["compatibilità", "integrazione", "connessione"],
        "scalabilità": ["adattabilità", "flessibilità", "espandibilità"],
        "capillarità": ["diffusione", "presenza", "copertura"],
        "incrementare": ["aumentare", "accrescere", "far crescere"],
        "decrementare": ["diminuire", "ridurre", "calare"],
        "esternalizzare": ["affidare fuori", "appaltare", "delegare"],
        "internalizzare": ["gestire internamente", "assumere", "incorporare"],
        "parametrizzare": ["definire i parametri", "misurare", "classificare"],
        "efficientare": ["rendere efficiente", "migliorare", "snellire"],
        "rendicontare": ["riferire", "documentare", "registrare"],
        "protocollare": ["registrare", "catalogare", "archiviare"],
        "normare": ["regolare", "disciplinare", "regolamentare"],
        "disfunzionale": ["inadeguato", "inefficace", "malfunzionante"],
        "propositivo": ["costruttivo", "attivo", "positivo"],
        "pervasivo": ["diffuso", "capillare", "esteso"],
        "iterativo": ["ripetuto", "ciclico", "ricorrente"],
        "funzionale": ["pratico", "utile", "efficace"],
        "strategico": ["chiave", "cruciale", "tattico"],
        "organico": ["completo", "strutturato", "coerente"],
        # === v0.12.0 expansion ===
        "abrogare": ["annullare", "abolire", "sopprimere"],
        "accreditare": ["certificare", "validare", "autorizzare"],
        "afferire": ["riguardare", "riferirsi", "essere attinente"],
        "agevolazione": ["facilitazione", "vantaggio", "beneficio"],
        "allocare": ["assegnare", "distribuire", "destinare"],
        "appurare": ["verificare", "accertare", "chiarire"],
        "attenuare": ["ridurre", "mitigare", "smorzare"],
        "capitalizzare": ["sfruttare", "valorizzare", "mettere a frutto"],
        "circostanziare": ["dettagliare", "precisare", "specificare"],
        "collimare": ["coincidere", "corrispondere", "concordare"],
        "comminare": ["infliggere", "imporre", "assegnare"],
        "compenetrare": ["fondere", "integrare", "unire"],
        "compulsare": ["consultare", "esaminare", "controllare"],
        "concepire": ["ideare", "inventare", "pensare"],
        "condizionare": ["influenzare", "determinare", "limitare"],
        "confutare": ["smentire", "contestare", "negare"],
        "corredare": ["accompagnare", "fornire", "completare"],
        "declinare": ["rifiutare", "respingere", "scartare"],
        "deferire": ["trasmettere", "affidare", "rimettere"],
        "derogare": ["deviare", "cambiare", "modificare"],
        "disapplicare": ["non applicare", "escludere", "omettere"],
        "disattendere": ["ignorare", "trascurare", "non rispettare"],
        "eccepire": ["obiettare", "contestare", "opporsi"],
        "eludere": ["evitare", "aggirare", "sfuggire"],
        "emendare": ["correggere", "modificare", "rettificare"],
        "equiparare": ["parificare", "uguagliare", "pareggiare"],
        "erogare": ["fornire", "distribuire", "concedere"],
        "esperire": ["tentare", "provare", "avviare"],
        "estrinsecabile": ["manifestabile", "esprimibile", "visibile"],
        "fattuale": ["concreto", "reale", "effettivo"],
        "fisiologico": ["naturale", "normale", "atteso"],
        "giuridico": ["legale", "di legge", "normativo"],
        "incardinare": ["inserire", "collocare", "integrare"],
        "interdire": ["vietare", "proibire", "impedire"],
        "interpellare": ["interrogare", "chiedere", "consultare"],
        "invalidare": ["annullare", "rendere nullo", "cancellare"],
        "irrogare": ["comminare", "infliggere", "imporre"],
        "legittimare": ["giustificare", "autorizzare", "validare"],
        "lesionare": ["danneggiare", "ferire", "compromettere"],
        "liquidare": ["pagare", "saldare", "estinguere"],
        "notificare": ["comunicare", "avvisare", "informare"],
        "obliterare": ["cancellare", "eliminare", "annullare"],
        "oneroso": ["costoso", "gravoso", "pesante"],
        "ostacolare": ["impedire", "frenare", "bloccare"],
        "palese": ["evidente", "chiaro", "manifesto"],
        "patrocinare": ["sponsorizzare", "sostenere", "promuovere"],
        "permeare": ["pervadere", "impegnare", "diffondere"],
        "perpetrare": ["compiere", "commettere", "realizzare"],
        "prefigurare": ["prevedere", "anticipare", "immaginare"],
        "prescrivere": ["ordinare", "imporre", "stabilire"],
        "principiare": ["iniziare", "cominciare", "avviare"],
        "profilare": ["delineare", "tracciare", "definire"],
        "promulgare": ["emanare", "pubblicare", "proclamare"],
        "ratificare": ["confermare", "approvare", "validare"],
        "rettificare": ["correggere", "modificare", "emendare"],
        "rimodulare": ["modificare", "adattare", "rivedere"],
        "sanare": ["risolvere", "correggere", "rimediare"],
        "scrutinare": ["esaminare", "analizzare", "vagliare"],
        "segnatamente": ["in particolare", "specialmente", "soprattutto"],
        "sondare": ["esplorare", "indagare", "tastare"],
        "soprassedere": ["rinviare", "sospendere", "rimandare"],
        "sopperire": ["supplire", "compensare", "rimediare"],
        "statuire": ["stabilire", "decretare", "decidere"],
        "stipulare": ["firmare", "concludere", "siglare"],
        "surrogare": ["sostituire", "rimpiazzare", "supplire"],
        "tutelare": ["proteggere", "difendere", "salvaguardare"],
        "valicare": ["superare", "oltrepassare", "scavalcare"],
        "vagliare": ["esaminare", "valutare", "analizzare"],
        "vincolante": ["obbligatorio", "imperativo", "cogente"],
        "antergico": ["sinergico", "collaborativo", "coordinato"],
        "capillare": ["diffuso", "esteso", "ramificato"],
        "contestuale": ["simultaneo", "concomitante", "parallelo"],
        "discrezionale": ["facoltativo", "a scelta", "libero"],
        "esaustivamente": ["completamente", "pienamente", "interamente"],
        "inderogabile": ["obbligatorio", "imprescindibile", "irrinunciabile"],
    },

    "bureaucratic_phrases": {
        "è doveroso sottolineare": ["va detto", "bisogna dire"],
        "nell'ambito di": ["in", "dentro", "durante"],
        "al fine di": ["per", "allo scopo di"],
        "in relazione a": ["riguardo a", "su", "per"],
        "in considerazione di": ["dato", "visto", "considerando"],
        "in maniera significativa": ["molto", "parecchio", "nettamente"],
        "riveste un ruolo cruciale": ["è molto importante", "conta molto"],
        "assume un'importanza": ["è importante", "conta"],
        "risulta necessario": ["bisogna", "serve", "occorre"],
        "per quanto concerne": ["per quanto riguarda", "riguardo a"],
        # === v0.10.0 ===
        "appare evidente che": ["si vede che", "è chiaro che"],
        "alla luce di": ["dato", "visto", "considerando"],
        "ai fini di": ["per", "allo scopo di"],
        "in primo luogo": ["prima di tutto", "anzitutto"],
        "in ultima analisi": ["alla fine", "insomma"],
        "a titolo esemplificativo": ["per esempio", "ad esempio"],
        "tenuto conto di": ["dato", "considerando", "visto che"],
        "con riferimento a": ["riguardo a", "in merito a", "su"],
        "a prescindere da": ["a parte", "senza contare", "indipendentemente"],
        "in virtù di": ["grazie a", "per", "in forza di"],
        "ai sensi di": ["secondo", "in base a", "conformemente a"],
        "nella fattispecie": ["in questo caso", "qui"],
        "in ottemperanza a": ["secondo", "conformemente a", "rispettando"],
        "a fronte di": ["davanti a", "rispetto a", "considerando"],
        "per converso": ["al contrario", "d'altra parte", "invece"],
        "fatto salvo": ["eccetto", "tranne", "a meno che"],
        # === v0.11.0 massive expansion ===
        "è opportuno precisare che": ["va detto che", "bisogna dire che"],
        "si rende necessario": ["bisogna", "occorre", "serve"],
        "con l'intento di": ["per", "allo scopo di", "al fine di"],
        "in ragione di": ["a causa di", "per via di", "per"],
        "a seguito di": ["dopo", "in seguito a", "per"],
        "in merito a": ["riguardo a", "su", "circa"],
        "dal punto di vista di": ["per", "secondo", "rispetto a"],
        "nel contesto di": ["in", "durante", "entro"],
        "a livello di": ["per quanto riguarda", "riguardo a", "in termini di"],
        "è d'uopo": ["è necessario", "bisogna", "serve"],
        "si rende opportuno": ["è bene", "conviene", "è meglio"],
        "in seno a": ["all'interno di", "in", "dentro"],
        "a monte di": ["prima di", "alla base di"],
        "a valle di": ["dopo", "in seguito a", "come risultato di"],
        "preme sottolineare": ["va detto", "è importante dire"],
        "giova ricordare che": ["va ricordato che", "è bene ricordare"],
        "non si può prescindere da": ["è necessario", "bisogna considerare"],
        "si fa presente che": ["si comunica che", "si avvisa che"],
        "con precipuo riferimento a": ["con riguardo a", "riguardo a", "su"],
        "in linea con": ["secondo", "in accordo con", "seguendo"],
        # === v0.12.0 expansion ===
        "ai fini del presente": ["per questo", "allo scopo di"],
        "a tal uopo": ["a tal fine", "per questo", "a questo scopo"],
        "con specifico riguardo a": ["riguardo a", "parlando di"],
        "dar luogo a": ["causare", "provocare", "creare"],
        "in conformità a": ["secondo", "come stabilito da", "conforme a"],
        "in deroga a": ["in eccezione a", "contrariamente a"],
        "in forza di": ["grazie a", "per", "in base a"],
        "in ossequio a": ["secondo", "rispettando", "conformemente a"],
        "in punto di": ["riguardo a", "quanto a", "per ciò che concerne"],
        "mettere in campo": ["usare", "impiegare", "attivare"],
        "nella misura in cui": ["se", "in quanto", "dato che"],
        "non da ultimo": ["inoltre", "anche", "per giunta"],
        "porre in essere": ["realizzare", "attuare", "fare"],
        "prendere atto di": ["riconoscere", "notare", "registrare"],
        "procedere alla": ["fare la", "eseguire la", "avviare la"],
        "salvo quanto previsto": ["tranne dove indicato", "eccetto"],
        "sulla scorta di": ["in base a", "sulla base di", "partendo da"],
        "tenere presente che": ["ricordare che", "considerare che"],
        "ciò premesso": ["detto questo", "fatto sta che"],
        "fatti salvi": ["eccetto", "tranne", "escludendo"],
        "onde evitare": ["per evitare", "al fine di non"],
        "per le finalità di cui": ["per gli scopi di", "per quanto riguarda"],
        "previo accordo": ["dopo aver concordato", "previa intesa"],
        "ad ogni buon conto": ["in ogni caso", "comunque"],
        "si precisa che": ["va detto che", "precisiamo che"],
    },

    "ai_connectors": {
        "Inoltre": ["In più", "Anche", "Per di più", "Poi"],
        "Tuttavia": ["Ma", "Però", "Eppure", "Ciononostante"],
        "Di conseguenza": ["Quindi", "Perciò", "Così", "Dunque"],
        "Ciononostante": ["Ma", "Tuttavia", "Eppure"],
        "Per di più": ["In più", "Inoltre", "Anche"],
        "In definitiva": ["Alla fine", "In conclusione", "Insomma"],
        "A tal proposito": ["A questo punto", "In merito"],
        "È importante sottolineare": ["Va detto", "Bisogna dire"],
        "Vale la pena notare": ["Da notare", "Interessante è"],
        "In conclusione": ["Per concludere", "Alla fine"],
        "Pertanto": ["Quindi", "Perciò", "Dunque"],
        "Altresì": ["Anche", "Inoltre", "Pure"],
        # === v0.10.0 ===
        "Ciò premesso": ["Detto questo", "In ogni caso"],
        "In ogni caso": ["Comunque", "Ad ogni modo"],
        "Parallelamente": ["Allo stesso tempo", "Inoltre"],
        "A maggior ragione": ["Tanto più", "Ancora di più"],
        "Analogamente": ["In modo simile", "Allo stesso modo"],
        "Effettivamente": ["In effetti", "Sì", "È vero"],
        "Indubbiamente": ["Senza dubbio", "Certamente"],
        "Nella fattispecie": ["In questo caso", "Qui"],
        # === v0.11.0 massive expansion ===
        "In aggiunta": ["In più", "Anche", "Poi"],
        "Nondimeno": ["Tuttavia", "Ma", "Eppure"],
        "In sostanza": ["In pratica", "Fondamentalmente", "In breve"],
        "Per quanto riguarda": ["Riguardo a", "In merito a", "Su"],
        "D'altro canto": ["D'altra parte", "Ma", "Tuttavia"],
        "Senza dubbio": ["Certamente", "Sicuramente", "Di certo"],
        "A questo proposito": ["In merito", "Su questo punto", "Riguardo a ciò"],
        "In secondo luogo": ["Poi", "Anche", "Inoltre"],
        "Conseguentemente": ["Di conseguenza", "Quindi", "Perciò"],
        "Contestualmente": ["Allo stesso tempo", "Nello stesso momento", "Intanto"],
        "In primo luogo": ["Prima di tutto", "Anzitutto", "Per cominciare"],
        "In terzo luogo": ["Infine", "Poi", "Ancora"],
        "Da un lato": ["Per certi aspetti", "In parte"],
        "Dall'altro lato": ["D'altra parte", "Però", "Ma"],
        "È altresì rilevante": ["Va anche detto", "Anche"],
        "In ultima istanza": ["Alla fine", "In definitiva", "Insomma"],
        "Più specificamente": ["Nello specifico", "In dettaglio", "Precisamente"],
        "In particolare": ["Nello specifico", "Specialmente", "Soprattutto"],
        # === v0.12.0 expansion ===
        "Detto ciò": ["Però", "Tuttavia", "Comunque"],
        "Ciò nonostante": ["Eppure", "Tuttavia", "Ma"],
        "Per inciso": ["Tra parentesi", "A proposito", "Di sfuggita"],
        "A ben guardare": ["Se si osserva", "Guardando meglio", "In realtà"],
        "A onor del vero": ["Per la verità", "In tutta franchezza"],
        "A tal riguardo": ["In merito", "Su questo", "Riguardo a ciò"],
        "A titolo di esempio": ["Per esempio", "Ad esempio"],
        "Come si può notare": ["Come si vede", "Si nota che"],
        "Da notare che": ["Va notato che", "Si noti che"],
        "Di fatto": ["In pratica", "Concretamente", "Nella realtà"],
        "Ebbene": ["Allora", "Dunque", "Orbene"],
        "In altri termini": ["In altre parole", "Cioè", "Ossia"],
        "In breve": ["In poche parole", "Riassumendo", "Per farla breve"],
        "In buona sostanza": ["In pratica", "Di fatto", "Sostanzialmente"],
        "In effetti": ["Di fatto", "A dire il vero", "Effettivamente"],
        "In ultima analisi": ["Alla fine", "In definitiva", "In conclusione"],
        "Occorre precisare": ["Va precisato", "Bisogna dire"],
        "Per contro": ["Al contrario", "D'altra parte", "Invece"],
        "Però": ["Ma", "Tuttavia", "Eppure"],
        "Più precisamente": ["In modo più preciso", "Nello specifico"],
        "Resta il fatto che": ["Rimane il fatto che", "Si deve ammettere"],
        "Stando così le cose": ["Data la situazione", "Pertanto"],
        "Tutto sommato": ["In fin dei conti", "Tutto considerato"],
        "Va da sé che": ["Naturalmente", "Ovviamente", "Si capisce"],
        "Volendo riassumere": ["In sintesi", "Per riassumere", "In breve"],
    },

    "synonyms": {
        "importante": ["rilevante", "significativo", "essenziale"],
        "grande": ["ampio", "vasto", "considerevole"],
        "piccolo": ["ridotto", "modesto", "esiguo"],
        "veloce": ["rapido", "agile", "pronto"],
        "problema": ["difficoltà", "sfida", "ostacolo"],
        "soluzione": ["risposta", "via d'uscita", "rimedio"],
        "risultato": ["esito", "effetto", "frutto"],
        "metodo": ["approccio", "tecnica", "sistema"],
        "processo": ["procedura", "percorso", "iter"],
        "obiettivo": ["scopo", "traguardo", "meta"],
        "vantaggio": ["beneficio", "plus", "punto di forza"],
        "sviluppo": ["evoluzione", "progresso", "crescita"],
        "analisi": ["studio", "esame", "indagine"],
        "efficace": ["efficiente", "produttivo", "funzionale"],
        "complesso": ["complicato", "articolato", "elaborato"],
        "moderno": ["attuale", "contemporaneo", "odierno"],
        "qualità": ["livello", "standard", "valore"],
        # === v0.10.0 ===
        "essenziale": ["fondamentale", "cruciale", "vitale"],
        "situazione": ["contesto", "caso", "scenario"],
        "strategia": ["piano", "tattica", "approccio"],
        "concetto": ["idea", "nozione", "principio"],
        "struttura": ["quadro", "organizzazione", "impalcatura"],
        "capacità": ["competenza", "abilità", "potenziale"],
        "influenza": ["impatto", "effetto", "peso"],
        "prospettiva": ["visione", "punto di vista", "angolo"],
        "dinamica": ["movimento", "slancio", "tendenza"],
        "elemento": ["componente", "parte", "fattore"],
        "sistema": ["meccanismo", "apparato", "insieme"],
        "risorsa": ["mezzo", "strumento", "fonte"],
        "dimensione": ["aspetto", "sfaccettatura", "lato"],
        "contesto": ["ambiente", "quadro", "sfondo"],
        "sfida": ["prova", "ostacolo", "difficoltà"],
        "evoluzione": ["cambiamento", "progresso", "trasformazione"],
        "contributo": ["apporto", "partecipazione", "aiuto"],
        "esperienza": ["vissuto", "pratica", "know-how"],
        "inoltre": ["anche", "pure", "altresì"],
        "necessario": ["indispensabile", "richiesto", "obbligatorio"],
        # === v0.11.0 massive expansion ===
        "difficile": ["arduo", "complicato", "impegnativo"],
        "facile": ["semplice", "agevole", "elementare"],
        "bello": ["piacevole", "gradevole", "attraente"],
        "brutto": ["sgradevole", "orribile", "spiacevole"],
        "buono": ["valido", "positivo", "eccellente"],
        "cattivo": ["pessimo", "negativo", "scadente"],
        "nuovo": ["recente", "fresco", "inedito"],
        "vecchio": ["antico", "datato", "obsoleto"],
        "forte": ["potente", "robusto", "intenso"],
        "debole": ["fragile", "fiacco", "scarso"],
        "lungo": ["prolungato", "esteso", "duraturo"],
        "breve": ["corto", "conciso", "sintetico"],
        "chiaro": ["limpido", "evidente", "palese"],
        "scuro": ["cupo", "buio", "oscuro"],
        "ricco": ["abbondante", "copioso", "florido"],
        "povero": ["scarso", "misero", "carente"],
        "alto": ["elevato", "superiore", "notevole"],
        "basso": ["ridotto", "inferiore", "contenuto"],
        "giusto": ["corretto", "appropriato", "adatto"],
        "sbagliato": ["errato", "scorretto", "improprio"],
        "possibile": ["fattibile", "realizzabile", "attuabile"],
        "impossibile": ["irrealizzabile", "impraticabile", "utopistico"],
        "necessità": ["bisogno", "esigenza", "urgenza"],
        "opportunità": ["occasione", "possibilità", "chance"],
        "cambiamento": ["modifica", "variazione", "trasformazione"],
        "crescita": ["aumento", "incremento", "espansione"],
        "calo": ["diminuzione", "ribasso", "contrazione"],
        "lavoro": ["attività", "impiego", "occupazione"],
        "progetto": ["piano", "iniziativa", "programma"],
        "accordo": ["intesa", "patto", "convenzione"],
        "decisione": ["scelta", "delibera", "risoluzione"],
        "comunicazione": ["messaggio", "informazione", "avviso"],
        "valutazione": ["giudizio", "stima", "esame"],
        "conoscenza": ["sapere", "competenza", "nozione"],
        "ruolo": ["funzione", "compito", "parte"],
        "impatto": ["effetto", "conseguenza", "ripercussione"],
        "settore": ["ambito", "campo", "area"],
        "aspetto": ["punto", "lato", "dettaglio"],
        "livello": ["grado", "piano", "stadio"],
        "modo": ["maniera", "forma", "stile"],
        "tipo": ["genere", "sorta", "categoria"],
        "area": ["zona", "regione", "settore"],
        "parte": ["porzione", "sezione", "fetta"],
        "fase": ["stadio", "momento", "tappa"],
        "punto": ["aspetto", "questione", "elemento"],
        "dato": ["informazione", "cifra", "indicatore"],
        "azione": ["intervento", "iniziativa", "passo"],
        "effetto": ["conseguenza", "risultato", "esito"],
        "causa": ["motivo", "ragione", "origine"],
        "fine": ["scopo", "obiettivo", "traguardo"],
        "inizio": ["avvio", "partenza", "principio"],
        "termine": ["fine", "conclusione", "scadenza"],
        "condizione": ["stato", "requisito", "circostanza"],
        "proposta": ["offerta", "suggerimento", "idea"],
        "esempio": ["caso", "modello", "campione"],
        "caratteristica": ["proprietà", "tratto", "qualità"],
        "funzione": ["ruolo", "compito", "mansione"],
        "relazione": ["rapporto", "legame", "connessione"],
        "risposta": ["replica", "reazione", "feedback"],
        "domanda": ["richiesta", "quesito", "interrogativo"],
        "attività": ["azione", "operazione", "lavoro"],
        "interesse": ["attenzione", "curiosità", "coinvolgimento"],
        "valore": ["pregio", "merito", "importanza"],
        "rischio": ["pericolo", "minaccia", "insidia"],
        "stato": ["condizione", "situazione", "posizione"],
        "utilizzo": ["uso", "impiego", "applicazione"],
        "miglioramento": ["progresso", "avanzamento", "ottimizzazione"],
        "obiettivamente": ["in realtà", "di fatto", "concretamente"],
        "sostanzialmente": ["in pratica", "di fatto", "essenzialmente"],
        "significativamente": ["notevolmente", "considerevolmente", "molto"],
        "adeguato": ["appropriato", "idoneo", "conforme"],
        "specifico": ["particolare", "preciso", "determinato"],
        "generale": ["complessivo", "globale", "ampio"],
        "particolare": ["specifico", "singolare", "unico"],
        "diverso": ["differente", "vario", "distinto"],
        "simile": ["analogo", "affine", "comparabile"],
        "costante": ["continuo", "stabile", "fisso"],
        "variabile": ["mutevole", "incostante", "instabile"],
        "reale": ["effettivo", "concreto", "vero"],
        "potenziale": ["possibile", "eventuale", "latente"],
        "attuale": ["corrente", "presente", "vigente"],
        "precedente": ["anteriore", "passato", "pregresso"],
        "successivo": ["seguente", "prossimo", "posteriore"],
        "recente": ["ultimo", "fresco", "nuovo"],
        "frequente": ["comune", "abituale", "ricorrente"],
        # === v0.12.0 expansion ===
        "rapido": ["celere", "svelto", "sollecito"],
        "lento": ["graduale", "flemmatico", "posato"],
        "preciso": ["esatto", "accurato", "puntuale"],
        "vago": ["impreciso", "generico", "indefinito"],
        "solido": ["robusto", "stabile", "saldo"],
        "fragile": ["delicato", "vulnerabile", "precario"],
        "ampio": ["esteso", "largo", "vasto"],
        "limitato": ["ristretto", "contenuto", "circoscritto"],
        "provvisorio": ["temporaneo", "transitorio", "passeggero"],
        "definitivo": ["finale", "conclusivo", "irreversibile"],
        "parziale": ["incompleto", "frammentario", "limitato"],
        "integrale": ["completo", "totale", "intero"],
        "evidente": ["palese", "manifesto", "lampante"],
        "frequentemente": ["spesso", "di frequente", "regolarmente"],
        "raramente": ["di rado", "poco", "sporadicamente"],
        "probabilmente": ["forse", "verosimilmente", "presumibilmente"],
        "sicuramente": ["certamente", "di certo", "senza dubbio"],
        "pienamente": ["completamente", "interamente", "del tutto"],
        "leggermente": ["appena", "un po'", "lievemente"],
        "profondamente": ["intensamente", "fortemente", "molto"],
        "considerevole": ["notevole", "consistente", "rilevante"],
        "trascurabile": ["irrilevante", "insignificante", "minimo"],
        "ragione": ["motivo", "causa", "fondamento"],
        "errore": ["sbaglio", "svista", "inesattezza"],
        "successo": ["riuscita", "buon esito", "trionfo"],
        "fallimento": ["insuccesso", "sconfitta", "fiasco"],
        "dubbio": ["incertezza", "perplessità", "esitazione"],
        "certezza": ["sicurezza", "convinzione", "garanzia"],
        "pericolo": ["rischio", "minaccia", "insidia"],
        "limite": ["confine", "soglia", "barriera"],
        "origine": ["provenienza", "fonte", "radice"],
        "scopo": ["fine", "obiettivo", "finalità"],
        "norma": ["regola", "legge", "disposizione"],
        "esigenza": ["necessità", "bisogno", "richiesta"],
        "creare": ["produrre", "realizzare", "generare"],
        "ridurre": ["diminuire", "calare", "abbassare"],
        "aumentare": ["accrescere", "innalzare", "incrementare"],
        "ottenere": ["raggiungere", "conquistare", "conseguire"],
        "fornire": ["dare", "offrire", "mettere a disposizione"],
        "sostenere": ["supportare", "appoggiare", "difendere"],
        "affrontare": ["gestire", "risolvere", "fronteggiare"],
        "confermare": ["ribadire", "avvalorare", "attestare"],
        "prevedere": ["anticipare", "programmare", "aspettarsi"],
        "ampliare": ["estendere", "allargare", "espandere"],
        "coinvolgere": ["includere", "incorporare", "interessare"],
        "rilevare": ["notare", "osservare", "constatare"],
    },

    "sentence_starters": {
        "Questo": ["Tale", "Un tale", "Il presente"],
        "Lui": ["La persona", "Il soggetto", "L'individuo"],
        "Lei": ["La persona", "La specialista", "L'autrice"],
        "Loro": ["Quelli", "Il team", "Queste persone"],
        "Noi": ["Il nostro team", "Il gruppo", "Tutti noi"],
        "Il": ["Un", "Ogni", "Questo"],
        "La": ["Una", "Questa", "Ogni"],
        "Le": ["Delle", "Queste", "Alcune"],
        "In": ["All'interno di", "Durante", "Nel corso di"],
        "Per": ["Al fine di", "Allo scopo di", "In vista di"],
        "Anche": ["Inoltre", "Ugualmente", "Pure"],
        # === v0.10.0 ===
        "Così": ["In questo modo", "Quindi", "Pertanto"],
        "Sebbene": ["Anche se", "Benché", "Nonostante"],
        # === v0.11.0 massive expansion ===
        "Questi": ["Tali", "I presenti", "Siffatti"],
        "Queste": ["Tali", "Siffatte", "Le presenti"],
        "Gli": ["I", "Alcuni", "Certi"],
        "Un": ["Il", "Ogni", "Ciascun"],
        "Una": ["La", "Ogni", "Ciascuna"],
        "I": ["Dei", "Alcuni", "Certi"],
        "Lo": ["Il", "Un", "Questo"],
        "Ci": ["Noi", "Vi", "Esistono"],
        "Si": ["Esso", "La cosa", "Ciò"],
        "È": ["Risulta", "Appare", "Sembra"],
        "Come": ["Così come", "In quanto", "Nel ruolo di"],
        "Quando": ["Nel momento in cui", "Allorché", "Ogni volta che"],
        "Se": ["Nel caso in cui", "Qualora", "Laddove"],
        "Con": ["Mediante", "Attraverso", "Tramite"],
        "Da": ["A partire da", "Fin da", "Sin da"],
        "Non": ["Mai", "In nessun caso", "Per niente"],
        "Dopo": ["In seguito", "Successivamente", "A seguire"],
        "Prima": ["Inizialmente", "All'inizio", "In precedenza"],
        "Quindi": ["Perciò", "Di conseguenza", "Pertanto"],
        "Mentre": ["Nel frattempo", "Intanto", "Durante"],
        "Già": ["Ormai", "A questo punto", "Sin d'ora"],
        "Ancora": ["Tuttora", "Sempre", "Di nuovo"],
        "Questo significa": ["Vuol dire", "In pratica", "Cioè"],
        # === v0.12.0 expansion ===
        "Qui": ["In questo luogo", "A questo punto", "In tale sede"],
        "Oggi": ["Al giorno d'oggi", "Attualmente", "Oggigiorno"],
        "Spesso": ["Frequentemente", "Di frequente", "Molte volte"],
        "Forse": ["Probabilmente", "Può darsi", "Eventualmente"],
        "Certamente": ["Sicuramente", "Senza dubbio", "Di certo"],
        "Ovviamente": ["Chiaramente", "Naturalmente", "Evidentemente"],
        "Generalmente": ["Di solito", "In genere", "Normalmente"],
        "Inizialmente": ["All'inizio", "In principio", "Dapprima"],
        "Infine": ["Alla fine", "Per concludere", "In ultimo"],
        "Apparentemente": ["A quanto pare", "A prima vista", "Sembrerebbe"],
        "Fortunatamente": ["Per fortuna", "Per buona sorte"],
        "Purtroppo": ["Sfortunatamente", "Ahimè", "Malauguratamente"],
        "Precisamente": ["Esattamente", "Proprio", "Per l'appunto"],
    },

    "colloquial_markers": [
        "onestamente", "in realtà", "in fondo",
        "diciamo", "in pratica", "tra l'altro",
        "per essere onesti", "tra di noi", "detto fra noi",
        "curiosamente", "per la verità",
        "a ben vedere", "per così dire",
        "alla fin fine", "in fin dei conti", "a proposito",
        # === v0.10.0 ===
        "insomma", "beh", "mah", "personalmente",
        "francamente", "va be'", "tanto per dire",
        "senza giri di parole", "ad essere sinceri", "ora",
        # === v0.11.0 massive expansion ===
        "a dire il vero", "per carità", "sai",
        "ecco", "cioè", "comunque",
        "praticamente", "fondamentalmente", "sinceramente",
        "in effetti", "guarda", "tipo",
        "magari", "per fortuna", "purtroppo",
        "in poche parole", "tanto", "alla fine",
        "per dire", "figurati", "non a caso",
        "ovviamente", "chiaramente", "evidentemente",
        "per inciso", "tra parentesi", "come dire",
        "in sostanza", "diciamo così", "a essere precisi",
        "per essere chiari", "a voler essere sinceri",
        "da un certo punto di vista",
        # === v0.12.0 expansion ===
        "se devo essere sincero", "la questione è che",
        "chiamiamo le cose col loro nome", "non nascondiamoci",
        "in parole semplici", "con tutto il rispetto",
        "per farla breve", "che dire",
        "sia chiaro", "detto tra noi",
        "se posso permettermi", "non a torto",
        "va detto", "parliamoci chiaro",
        "onestamente parlando", "la verità è che",
        "inutile girarci intorno", "bisogna ammetterlo",
        "a essere franchi", "senza mezzi termini",
    ],

    "abbreviations": [
        "Sig.", "Sig.ra", "Dott.", "Prof.", "ecc.",
        "es.", "vol.", "pag.", "ed.", "cap.", "fig.",
        "S.p.A.", "S.r.l.", "v.", "p.za", "tel.", "rif.",
        "max.", "min.", "ca.", "app.",
        # === v0.10.0 ===
        "N.B.", "P.S.", "n.", "dip.", "dir.",
        "amm.", "gov.", "sez.", "suppl.", "agg.",
        # === v0.11.0 massive expansion ===
        "Avv.", "Ing.", "Arch.", "Geom.", "Rag.",
        "On.", "Ill.mo", "Spett.le", "c.a.", "p.v.",
        "u.s.", "c.m.", "f.to", "all.", "prot.",
        "circ.", "art.", "c.c.", "c.p.", "D.Lgs.",
        "D.P.R.", "lett.", "cc.", "cfr.", "ib.",
        "op. cit.", "par.", "tav.", "tab.", "Comm.",
        "Cav.", "gen.", "c.d.", "sgg.",
    ],

    "perplexity_boosters": [
        "per così dire", "a ben vedere", "in buona sostanza",
        "né più né meno", "di fatto", "ipso facto",
        "paradossalmente", "curiosamente", "ironicamente",
        "a rigore", "in un certo senso",
        "a conti fatti", "tutto sommato", "con riguardo a",
        "detto ciò", "sia come sia", "in ogni caso",
        "per quanto mi riguarda", "a dirla tutta",
        # === v0.10.0 ===
        "sta di fatto che", "comunque sia",
        "per amor del vero", "a onor del vero",
        "non c'è che dire", "a ben guardare",
        "volente o nolente", "come che sia",
        # === v0.11.0 massive expansion ===
        "per quanto ne sappia", "nella misura in cui",
        "a quanto pare", "sembrerebbe che",
        "sotto certi aspetti", "in teoria",
        "stando ai fatti", "in ultima analisi",
        "per certi versi", "da quel che si vede",
        "se non altro", "ammesso e non concesso",
        "a detta di molti", "in buona fede",
        "a tutti gli effetti", "con buona pace di",
        "per quanto possa sembrare strano",
        "in definitiva", "per la precisione",
        "non da ultimo", "a onor di cronaca",
        "per quanto paradossale", "con tutto il rispetto",
        "se vogliamo", "ad essere onesti",
        "con le dovute cautele", "in coscienza",
        "su per giù", "per certi aspetti",
        "a prescindere", "con ogni probabilità",
        "senza ombra di dubbio",
        "a giudicare dalle apparenze",
        # === v0.12.0 expansion ===
        "al netto di tutto", "malgrado tutto",
        "a voler esser pignoli", "ciò nondimeno",
        "ad essere pignoli", "guardando i fatti",
        "se non erro", "a quanto mi risulta",
        "per quel che vale", "fatto sta che",
        "che piaccia o no", "va detto con franchezza",
        "a torto o a ragione", "in fin dei conti",
        "per quanto ne sappia", "non si può negare",
        "stando ai dati", "per quanto strano possa sembrare",
        "non è un caso che", "a voler essere onesti",
    ],

    "profile_targets": {
        "chat": {"avg_len": (6, 16), "variance": 0.5},
        "web": {"avg_len": (8, 22), "variance": 0.4},
        "seo": {"avg_len": (10, 24), "variance": 0.3},
        "docs": {"avg_len": (10, 26), "variance": 0.3},
        "formal": {"avg_len": (12, 30), "variance": 0.25},
    },

    "conjunctions": ["e", "ma", "o", "né", "che", "poi"],

    "split_conjunctions": [
        " e ", " ma ", " tuttavia ", " mentre ",
        " sebbene ", " perché ", " poiché ",
        # === v0.10.0 ===
        " ciononostante ", " eppure ", " bensì ",
        " al contrario ", " pertanto ", " giacché ",
        # === v0.11.0 massive expansion ===
        " dunque ", " ovvero ", " oppure ",
        " ossia ", " nondimeno ", " benché ",
        " allorché ", " qualora ", " laddove ",
        " cosicché ", " affinché ", " purché ",
        " nonostante ", " malgrado ", " sicché ",
        " dopodiché ", " altrimenti ", " anziché ",
    ],
}
